from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.parameter_definition_spec import ParameterDefinitionSpec
    from ..models.sensor_definition_spec_parameters import (
        SensorDefinitionSpecParameters,
    )


T = TypeVar("T", bound="SensorDefinitionSpec")


@_attrs_define
class SensorDefinitionSpec:
    """
    Attributes:
        fields (Union[Unset, List['ParameterDefinitionSpec']]): List of fields that are parameters of a custom sensor.
            Those fields are used by the DQOps UI to display the data quality check editing screens with proper UI controls
            for all required fields.
        requires_event_timestamp (Union[Unset, bool]): The data quality sensor depends on the configuration of the event
            timestamp column name on the analyzed table. When true, the name of the column that stores the event
            (transaction, etc.) timestamp must be specified in the timestamp_columns.event_timestamp_column field on the
            table.
        requires_ingestion_timestamp (Union[Unset, bool]): The data quality sensor depends on the configuration of the
            ingestion timestamp column name on the analyzed table. When true, the name of the column that stores the
            ingestion (created_at, loaded_at, etc.) timestamp must be specified in the
            timestamp_columns.ingestion_timestamp_column field on the table.
        default_value (Union[Unset, float]): Default value that is used when the sensor returns no rows. A row count
            sensor may return no rows when a GROUP BY condition is added to capture the database server's local time zone.
            In order to always return a value, a sensor may have a default value configured.
        parameters (Union[Unset, SensorDefinitionSpecParameters]): Additional sensor definition parameters
    """

    fields: Union[Unset, List["ParameterDefinitionSpec"]] = UNSET
    requires_event_timestamp: Union[Unset, bool] = UNSET
    requires_ingestion_timestamp: Union[Unset, bool] = UNSET
    default_value: Union[Unset, float] = UNSET
    parameters: Union[Unset, "SensorDefinitionSpecParameters"] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        fields: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.fields, Unset):
            fields = []
            for fields_item_data in self.fields:
                fields_item = fields_item_data.to_dict()

                fields.append(fields_item)

        requires_event_timestamp = self.requires_event_timestamp
        requires_ingestion_timestamp = self.requires_ingestion_timestamp
        default_value = self.default_value
        parameters: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.parameters, Unset):
            parameters = self.parameters.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if fields is not UNSET:
            field_dict["fields"] = fields
        if requires_event_timestamp is not UNSET:
            field_dict["requires_event_timestamp"] = requires_event_timestamp
        if requires_ingestion_timestamp is not UNSET:
            field_dict["requires_ingestion_timestamp"] = requires_ingestion_timestamp
        if default_value is not UNSET:
            field_dict["default_value"] = default_value
        if parameters is not UNSET:
            field_dict["parameters"] = parameters

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.parameter_definition_spec import ParameterDefinitionSpec
        from ..models.sensor_definition_spec_parameters import (
            SensorDefinitionSpecParameters,
        )

        d = src_dict.copy()
        fields = []
        _fields = d.pop("fields", UNSET)
        for fields_item_data in _fields or []:
            fields_item = ParameterDefinitionSpec.from_dict(fields_item_data)

            fields.append(fields_item)

        requires_event_timestamp = d.pop("requires_event_timestamp", UNSET)

        requires_ingestion_timestamp = d.pop("requires_ingestion_timestamp", UNSET)

        default_value = d.pop("default_value", UNSET)

        _parameters = d.pop("parameters", UNSET)
        parameters: Union[Unset, SensorDefinitionSpecParameters]
        if isinstance(_parameters, Unset):
            parameters = UNSET
        else:
            parameters = SensorDefinitionSpecParameters.from_dict(_parameters)

        sensor_definition_spec = cls(
            fields=fields,
            requires_event_timestamp=requires_event_timestamp,
            requires_ingestion_timestamp=requires_ingestion_timestamp,
            default_value=default_value,
            parameters=parameters,
        )

        sensor_definition_spec.additional_properties = d
        return sensor_definition_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.single_store_db_load_balancing_mode import SingleStoreDbLoadBalancingMode
from ..types import UNSET, Unset

T = TypeVar("T", bound="SingleStoreDbParametersSpec")


@_attrs_define
class SingleStoreDbParametersSpec:
    """
    Attributes:
        load_balancing_mode (Union[Unset, SingleStoreDbLoadBalancingMode]):
        host_descriptions (Union[Unset, List[str]]): SingleStoreDB Host descriptions. Supports also a
            ${SINGLE_STORE_HOST_DESCRIPTIONS} configuration with a custom environment variable.
        schema (Union[Unset, str]): SingleStoreDB database/schema name. The value can be in the
            ${ENVIRONMENT_VARIABLE_NAME} format to use dynamic substitution.
        use_ssl (Union[Unset, bool]): Force enables SSL/TLS on the connection. Supports also a ${SINGLE_STORE_USE_SSL}
            configuration with a custom environment variable.
    """

    load_balancing_mode: Union[Unset, SingleStoreDbLoadBalancingMode] = UNSET
    host_descriptions: Union[Unset, List[str]] = UNSET
    schema: Union[Unset, str] = UNSET
    use_ssl: Union[Unset, bool] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        load_balancing_mode: Union[Unset, str] = UNSET
        if not isinstance(self.load_balancing_mode, Unset):
            load_balancing_mode = self.load_balancing_mode.value

        host_descriptions: Union[Unset, List[str]] = UNSET
        if not isinstance(self.host_descriptions, Unset):
            host_descriptions = self.host_descriptions

        schema = self.schema
        use_ssl = self.use_ssl

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if load_balancing_mode is not UNSET:
            field_dict["load_balancing_mode"] = load_balancing_mode
        if host_descriptions is not UNSET:
            field_dict["host_descriptions"] = host_descriptions
        if schema is not UNSET:
            field_dict["schema"] = schema
        if use_ssl is not UNSET:
            field_dict["use_ssl"] = use_ssl

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        _load_balancing_mode = d.pop("load_balancing_mode", UNSET)
        load_balancing_mode: Union[Unset, SingleStoreDbLoadBalancingMode]
        if isinstance(_load_balancing_mode, Unset):
            load_balancing_mode = UNSET
        else:
            load_balancing_mode = SingleStoreDbLoadBalancingMode(_load_balancing_mode)

        host_descriptions = cast(List[str], d.pop("host_descriptions", UNSET))

        schema = d.pop("schema", UNSET)

        use_ssl = d.pop("use_ssl", UNSET)

        single_store_db_parameters_spec = cls(
            load_balancing_mode=load_balancing_mode,
            host_descriptions=host_descriptions,
            schema=schema,
            use_ssl=use_ssl,
        )

        single_store_db_parameters_spec.additional_properties = d
        return single_store_db_parameters_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.column_accepted_values_monthly_partitioned_checks_spec_custom_checks import (
        ColumnAcceptedValuesMonthlyPartitionedChecksSpecCustomChecks,
    )
    from ..models.column_expected_numbers_in_use_count_check_spec import (
        ColumnExpectedNumbersInUseCountCheckSpec,
    )
    from ..models.column_expected_text_values_in_use_count_check_spec import (
        ColumnExpectedTextValuesInUseCountCheckSpec,
    )
    from ..models.column_expected_texts_in_top_values_count_check_spec import (
        ColumnExpectedTextsInTopValuesCountCheckSpec,
    )
    from ..models.column_number_found_in_set_percent_check_spec import (
        ColumnNumberFoundInSetPercentCheckSpec,
    )
    from ..models.column_text_found_in_set_percent_check_spec import (
        ColumnTextFoundInSetPercentCheckSpec,
    )
    from ..models.column_text_valid_country_code_percent_check_spec import (
        ColumnTextValidCountryCodePercentCheckSpec,
    )
    from ..models.column_text_valid_currency_code_percent_check_spec import (
        ColumnTextValidCurrencyCodePercentCheckSpec,
    )


T = TypeVar("T", bound="ColumnAcceptedValuesMonthlyPartitionedChecksSpec")


@_attrs_define
class ColumnAcceptedValuesMonthlyPartitionedChecksSpec:
    """
    Attributes:
        custom_checks (Union[Unset, ColumnAcceptedValuesMonthlyPartitionedChecksSpecCustomChecks]): Dictionary of
            additional custom checks within this category. The keys are check names defined in the definition section. The
            sensor parameters and rules should match the type of the configured sensor and rule for the custom check.
        monthly_partition_text_found_in_set_percent (Union[Unset, ColumnTextFoundInSetPercentCheckSpec]):
        monthly_partition_number_found_in_set_percent (Union[Unset, ColumnNumberFoundInSetPercentCheckSpec]):
        monthly_partition_expected_text_values_in_use_count (Union[Unset, ColumnExpectedTextValuesInUseCountCheckSpec]):
        monthly_partition_expected_texts_in_top_values_count (Union[Unset,
            ColumnExpectedTextsInTopValuesCountCheckSpec]):
        monthly_partition_expected_numbers_in_use_count (Union[Unset, ColumnExpectedNumbersInUseCountCheckSpec]):
        monthly_partition_text_valid_country_code_percent (Union[Unset, ColumnTextValidCountryCodePercentCheckSpec]):
        monthly_partition_text_valid_currency_code_percent (Union[Unset, ColumnTextValidCurrencyCodePercentCheckSpec]):
    """

    custom_checks: Union[
        Unset, "ColumnAcceptedValuesMonthlyPartitionedChecksSpecCustomChecks"
    ] = UNSET
    monthly_partition_text_found_in_set_percent: Union[
        Unset, "ColumnTextFoundInSetPercentCheckSpec"
    ] = UNSET
    monthly_partition_number_found_in_set_percent: Union[
        Unset, "ColumnNumberFoundInSetPercentCheckSpec"
    ] = UNSET
    monthly_partition_expected_text_values_in_use_count: Union[
        Unset, "ColumnExpectedTextValuesInUseCountCheckSpec"
    ] = UNSET
    monthly_partition_expected_texts_in_top_values_count: Union[
        Unset, "ColumnExpectedTextsInTopValuesCountCheckSpec"
    ] = UNSET
    monthly_partition_expected_numbers_in_use_count: Union[
        Unset, "ColumnExpectedNumbersInUseCountCheckSpec"
    ] = UNSET
    monthly_partition_text_valid_country_code_percent: Union[
        Unset, "ColumnTextValidCountryCodePercentCheckSpec"
    ] = UNSET
    monthly_partition_text_valid_currency_code_percent: Union[
        Unset, "ColumnTextValidCurrencyCodePercentCheckSpec"
    ] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        custom_checks: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.custom_checks, Unset):
            custom_checks = self.custom_checks.to_dict()

        monthly_partition_text_found_in_set_percent: Union[Unset, Dict[str, Any]] = (
            UNSET
        )
        if not isinstance(self.monthly_partition_text_found_in_set_percent, Unset):
            monthly_partition_text_found_in_set_percent = (
                self.monthly_partition_text_found_in_set_percent.to_dict()
            )

        monthly_partition_number_found_in_set_percent: Union[Unset, Dict[str, Any]] = (
            UNSET
        )
        if not isinstance(self.monthly_partition_number_found_in_set_percent, Unset):
            monthly_partition_number_found_in_set_percent = (
                self.monthly_partition_number_found_in_set_percent.to_dict()
            )

        monthly_partition_expected_text_values_in_use_count: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(
            self.monthly_partition_expected_text_values_in_use_count, Unset
        ):
            monthly_partition_expected_text_values_in_use_count = (
                self.monthly_partition_expected_text_values_in_use_count.to_dict()
            )

        monthly_partition_expected_texts_in_top_values_count: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(
            self.monthly_partition_expected_texts_in_top_values_count, Unset
        ):
            monthly_partition_expected_texts_in_top_values_count = (
                self.monthly_partition_expected_texts_in_top_values_count.to_dict()
            )

        monthly_partition_expected_numbers_in_use_count: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(self.monthly_partition_expected_numbers_in_use_count, Unset):
            monthly_partition_expected_numbers_in_use_count = (
                self.monthly_partition_expected_numbers_in_use_count.to_dict()
            )

        monthly_partition_text_valid_country_code_percent: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(
            self.monthly_partition_text_valid_country_code_percent, Unset
        ):
            monthly_partition_text_valid_country_code_percent = (
                self.monthly_partition_text_valid_country_code_percent.to_dict()
            )

        monthly_partition_text_valid_currency_code_percent: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(
            self.monthly_partition_text_valid_currency_code_percent, Unset
        ):
            monthly_partition_text_valid_currency_code_percent = (
                self.monthly_partition_text_valid_currency_code_percent.to_dict()
            )

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if custom_checks is not UNSET:
            field_dict["custom_checks"] = custom_checks
        if monthly_partition_text_found_in_set_percent is not UNSET:
            field_dict["monthly_partition_text_found_in_set_percent"] = (
                monthly_partition_text_found_in_set_percent
            )
        if monthly_partition_number_found_in_set_percent is not UNSET:
            field_dict["monthly_partition_number_found_in_set_percent"] = (
                monthly_partition_number_found_in_set_percent
            )
        if monthly_partition_expected_text_values_in_use_count is not UNSET:
            field_dict["monthly_partition_expected_text_values_in_use_count"] = (
                monthly_partition_expected_text_values_in_use_count
            )
        if monthly_partition_expected_texts_in_top_values_count is not UNSET:
            field_dict["monthly_partition_expected_texts_in_top_values_count"] = (
                monthly_partition_expected_texts_in_top_values_count
            )
        if monthly_partition_expected_numbers_in_use_count is not UNSET:
            field_dict["monthly_partition_expected_numbers_in_use_count"] = (
                monthly_partition_expected_numbers_in_use_count
            )
        if monthly_partition_text_valid_country_code_percent is not UNSET:
            field_dict["monthly_partition_text_valid_country_code_percent"] = (
                monthly_partition_text_valid_country_code_percent
            )
        if monthly_partition_text_valid_currency_code_percent is not UNSET:
            field_dict["monthly_partition_text_valid_currency_code_percent"] = (
                monthly_partition_text_valid_currency_code_percent
            )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.column_accepted_values_monthly_partitioned_checks_spec_custom_checks import (
            ColumnAcceptedValuesMonthlyPartitionedChecksSpecCustomChecks,
        )
        from ..models.column_expected_numbers_in_use_count_check_spec import (
            ColumnExpectedNumbersInUseCountCheckSpec,
        )
        from ..models.column_expected_text_values_in_use_count_check_spec import (
            ColumnExpectedTextValuesInUseCountCheckSpec,
        )
        from ..models.column_expected_texts_in_top_values_count_check_spec import (
            ColumnExpectedTextsInTopValuesCountCheckSpec,
        )
        from ..models.column_number_found_in_set_percent_check_spec import (
            ColumnNumberFoundInSetPercentCheckSpec,
        )
        from ..models.column_text_found_in_set_percent_check_spec import (
            ColumnTextFoundInSetPercentCheckSpec,
        )
        from ..models.column_text_valid_country_code_percent_check_spec import (
            ColumnTextValidCountryCodePercentCheckSpec,
        )
        from ..models.column_text_valid_currency_code_percent_check_spec import (
            ColumnTextValidCurrencyCodePercentCheckSpec,
        )

        d = src_dict.copy()
        _custom_checks = d.pop("custom_checks", UNSET)
        custom_checks: Union[
            Unset, ColumnAcceptedValuesMonthlyPartitionedChecksSpecCustomChecks
        ]
        if isinstance(_custom_checks, Unset):
            custom_checks = UNSET
        else:
            custom_checks = (
                ColumnAcceptedValuesMonthlyPartitionedChecksSpecCustomChecks.from_dict(
                    _custom_checks
                )
            )

        _monthly_partition_text_found_in_set_percent = d.pop(
            "monthly_partition_text_found_in_set_percent", UNSET
        )
        monthly_partition_text_found_in_set_percent: Union[
            Unset, ColumnTextFoundInSetPercentCheckSpec
        ]
        if isinstance(_monthly_partition_text_found_in_set_percent, Unset):
            monthly_partition_text_found_in_set_percent = UNSET
        else:
            monthly_partition_text_found_in_set_percent = (
                ColumnTextFoundInSetPercentCheckSpec.from_dict(
                    _monthly_partition_text_found_in_set_percent
                )
            )

        _monthly_partition_number_found_in_set_percent = d.pop(
            "monthly_partition_number_found_in_set_percent", UNSET
        )
        monthly_partition_number_found_in_set_percent: Union[
            Unset, ColumnNumberFoundInSetPercentCheckSpec
        ]
        if isinstance(_monthly_partition_number_found_in_set_percent, Unset):
            monthly_partition_number_found_in_set_percent = UNSET
        else:
            monthly_partition_number_found_in_set_percent = (
                ColumnNumberFoundInSetPercentCheckSpec.from_dict(
                    _monthly_partition_number_found_in_set_percent
                )
            )

        _monthly_partition_expected_text_values_in_use_count = d.pop(
            "monthly_partition_expected_text_values_in_use_count", UNSET
        )
        monthly_partition_expected_text_values_in_use_count: Union[
            Unset, ColumnExpectedTextValuesInUseCountCheckSpec
        ]
        if isinstance(_monthly_partition_expected_text_values_in_use_count, Unset):
            monthly_partition_expected_text_values_in_use_count = UNSET
        else:
            monthly_partition_expected_text_values_in_use_count = (
                ColumnExpectedTextValuesInUseCountCheckSpec.from_dict(
                    _monthly_partition_expected_text_values_in_use_count
                )
            )

        _monthly_partition_expected_texts_in_top_values_count = d.pop(
            "monthly_partition_expected_texts_in_top_values_count", UNSET
        )
        monthly_partition_expected_texts_in_top_values_count: Union[
            Unset, ColumnExpectedTextsInTopValuesCountCheckSpec
        ]
        if isinstance(_monthly_partition_expected_texts_in_top_values_count, Unset):
            monthly_partition_expected_texts_in_top_values_count = UNSET
        else:
            monthly_partition_expected_texts_in_top_values_count = (
                ColumnExpectedTextsInTopValuesCountCheckSpec.from_dict(
                    _monthly_partition_expected_texts_in_top_values_count
                )
            )

        _monthly_partition_expected_numbers_in_use_count = d.pop(
            "monthly_partition_expected_numbers_in_use_count", UNSET
        )
        monthly_partition_expected_numbers_in_use_count: Union[
            Unset, ColumnExpectedNumbersInUseCountCheckSpec
        ]
        if isinstance(_monthly_partition_expected_numbers_in_use_count, Unset):
            monthly_partition_expected_numbers_in_use_count = UNSET
        else:
            monthly_partition_expected_numbers_in_use_count = (
                ColumnExpectedNumbersInUseCountCheckSpec.from_dict(
                    _monthly_partition_expected_numbers_in_use_count
                )
            )

        _monthly_partition_text_valid_country_code_percent = d.pop(
            "monthly_partition_text_valid_country_code_percent", UNSET
        )
        monthly_partition_text_valid_country_code_percent: Union[
            Unset, ColumnTextValidCountryCodePercentCheckSpec
        ]
        if isinstance(_monthly_partition_text_valid_country_code_percent, Unset):
            monthly_partition_text_valid_country_code_percent = UNSET
        else:
            monthly_partition_text_valid_country_code_percent = (
                ColumnTextValidCountryCodePercentCheckSpec.from_dict(
                    _monthly_partition_text_valid_country_code_percent
                )
            )

        _monthly_partition_text_valid_currency_code_percent = d.pop(
            "monthly_partition_text_valid_currency_code_percent", UNSET
        )
        monthly_partition_text_valid_currency_code_percent: Union[
            Unset, ColumnTextValidCurrencyCodePercentCheckSpec
        ]
        if isinstance(_monthly_partition_text_valid_currency_code_percent, Unset):
            monthly_partition_text_valid_currency_code_percent = UNSET
        else:
            monthly_partition_text_valid_currency_code_percent = (
                ColumnTextValidCurrencyCodePercentCheckSpec.from_dict(
                    _monthly_partition_text_valid_currency_code_percent
                )
            )

        column_accepted_values_monthly_partitioned_checks_spec = cls(
            custom_checks=custom_checks,
            monthly_partition_text_found_in_set_percent=monthly_partition_text_found_in_set_percent,
            monthly_partition_number_found_in_set_percent=monthly_partition_number_found_in_set_percent,
            monthly_partition_expected_text_values_in_use_count=monthly_partition_expected_text_values_in_use_count,
            monthly_partition_expected_texts_in_top_values_count=monthly_partition_expected_texts_in_top_values_count,
            monthly_partition_expected_numbers_in_use_count=monthly_partition_expected_numbers_in_use_count,
            monthly_partition_text_valid_country_code_percent=monthly_partition_text_valid_country_code_percent,
            monthly_partition_text_valid_currency_code_percent=monthly_partition_text_valid_currency_code_percent,
        )

        column_accepted_values_monthly_partitioned_checks_spec.additional_properties = d
        return column_accepted_values_monthly_partitioned_checks_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

if TYPE_CHECKING:
    from ..models.table_comparison_configuration_spec import (
        TableComparisonConfigurationSpec,
    )


T = TypeVar("T", bound="TableSpecTableComparisons")


@_attrs_define
class TableSpecTableComparisons:
    """Dictionary of data comparison configurations. Data comparison configurations are used for comparisons between data
    sources to compare this table (called the compared table) with other reference tables (the source of truth). The
    reference table's metadata must be imported into DQOps, but the reference table may be located in another data
    source. DQOps will compare metrics calculated for groups of rows (using the GROUP BY clause). For each comparison,
    the user must specify a name of a data grouping. The number of data grouping dimensions in the parent table and the
    reference table defined in the selected data grouping configurations must match. DQOps will run the same data
    quality sensors on both the parent table (table under test) and the reference table (the source of truth), comparing
    the measures (sensor readouts) captured from both tables.

    """

    additional_properties: Dict[str, "TableComparisonConfigurationSpec"] = _attrs_field(
        init=False, factory=dict
    )

    def to_dict(self) -> Dict[str, Any]:
        pass

        field_dict: Dict[str, Any] = {}
        for prop_name, prop in self.additional_properties.items():
            field_dict[prop_name] = prop.to_dict()

        field_dict.update({})

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.table_comparison_configuration_spec import (
            TableComparisonConfigurationSpec,
        )

        d = src_dict.copy()
        table_spec_table_comparisons = cls()

        additional_properties = {}
        for prop_name, prop_dict in d.items():
            additional_property = TableComparisonConfigurationSpec.from_dict(prop_dict)

            additional_properties[prop_name] = additional_property

        table_spec_table_comparisons.additional_properties = additional_properties
        return table_spec_table_comparisons

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> "TableComparisonConfigurationSpec":
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: "TableComparisonConfigurationSpec") -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.incident_counts_model import IncidentCountsModel


T = TypeVar("T", bound="IncidentSeverityLevelCountsModel")


@_attrs_define
class IncidentSeverityLevelCountsModel:
    """
    Attributes:
        warning_counts (Union[Unset, IncidentCountsModel]):
        error_counts (Union[Unset, IncidentCountsModel]):
        fatal_counts (Union[Unset, IncidentCountsModel]):
    """

    warning_counts: Union[Unset, "IncidentCountsModel"] = UNSET
    error_counts: Union[Unset, "IncidentCountsModel"] = UNSET
    fatal_counts: Union[Unset, "IncidentCountsModel"] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        warning_counts: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.warning_counts, Unset):
            warning_counts = self.warning_counts.to_dict()

        error_counts: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.error_counts, Unset):
            error_counts = self.error_counts.to_dict()

        fatal_counts: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.fatal_counts, Unset):
            fatal_counts = self.fatal_counts.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if warning_counts is not UNSET:
            field_dict["warningCounts"] = warning_counts
        if error_counts is not UNSET:
            field_dict["errorCounts"] = error_counts
        if fatal_counts is not UNSET:
            field_dict["fatalCounts"] = fatal_counts

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.incident_counts_model import IncidentCountsModel

        d = src_dict.copy()
        _warning_counts = d.pop("warningCounts", UNSET)
        warning_counts: Union[Unset, IncidentCountsModel]
        if isinstance(_warning_counts, Unset):
            warning_counts = UNSET
        else:
            warning_counts = IncidentCountsModel.from_dict(_warning_counts)

        _error_counts = d.pop("errorCounts", UNSET)
        error_counts: Union[Unset, IncidentCountsModel]
        if isinstance(_error_counts, Unset):
            error_counts = UNSET
        else:
            error_counts = IncidentCountsModel.from_dict(_error_counts)

        _fatal_counts = d.pop("fatalCounts", UNSET)
        fatal_counts: Union[Unset, IncidentCountsModel]
        if isinstance(_fatal_counts, Unset):
            fatal_counts = UNSET
        else:
            fatal_counts = IncidentCountsModel.from_dict(_fatal_counts)

        incident_severity_level_counts_model = cls(
            warning_counts=warning_counts,
            error_counts=error_counts,
            fatal_counts=fatal_counts,
        )

        incident_severity_level_counts_model.additional_properties = d
        return incident_severity_level_counts_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.table_comparison_results_model_column_comparison_results import (
        TableComparisonResultsModelColumnComparisonResults,
    )
    from ..models.table_comparison_results_model_table_comparison_results import (
        TableComparisonResultsModelTableComparisonResults,
    )


T = TypeVar("T", bound="TableComparisonResultsModel")


@_attrs_define
class TableComparisonResultsModel:
    """The table comparison results model with the summary information about the most recent table comparison that was
    performed.

        Attributes:
            table_comparison_results (Union[Unset, TableComparisonResultsModelTableComparisonResults]): The dictionary of
                comparison results between the tables for table level comparisons (e.g. row count). The keys for the dictionary
                are the check names. The value in the dictionary is a summary information about the most recent comparison.
            column_comparison_results (Union[Unset, TableComparisonResultsModelColumnComparisonResults]): The dictionary of
                comparison results between the tables for each compared column. The keys for the dictionary are the column
                names. The values are dictionaries of the data quality check names and their results.
    """

    table_comparison_results: Union[
        Unset, "TableComparisonResultsModelTableComparisonResults"
    ] = UNSET
    column_comparison_results: Union[
        Unset, "TableComparisonResultsModelColumnComparisonResults"
    ] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        table_comparison_results: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.table_comparison_results, Unset):
            table_comparison_results = self.table_comparison_results.to_dict()

        column_comparison_results: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.column_comparison_results, Unset):
            column_comparison_results = self.column_comparison_results.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if table_comparison_results is not UNSET:
            field_dict["table_comparison_results"] = table_comparison_results
        if column_comparison_results is not UNSET:
            field_dict["column_comparison_results"] = column_comparison_results

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.table_comparison_results_model_column_comparison_results import (
            TableComparisonResultsModelColumnComparisonResults,
        )
        from ..models.table_comparison_results_model_table_comparison_results import (
            TableComparisonResultsModelTableComparisonResults,
        )

        d = src_dict.copy()
        _table_comparison_results = d.pop("table_comparison_results", UNSET)
        table_comparison_results: Union[
            Unset, TableComparisonResultsModelTableComparisonResults
        ]
        if isinstance(_table_comparison_results, Unset):
            table_comparison_results = UNSET
        else:
            table_comparison_results = (
                TableComparisonResultsModelTableComparisonResults.from_dict(
                    _table_comparison_results
                )
            )

        _column_comparison_results = d.pop("column_comparison_results", UNSET)
        column_comparison_results: Union[
            Unset, TableComparisonResultsModelColumnComparisonResults
        ]
        if isinstance(_column_comparison_results, Unset):
            column_comparison_results = UNSET
        else:
            column_comparison_results = (
                TableComparisonResultsModelColumnComparisonResults.from_dict(
                    _column_comparison_results
                )
            )

        table_comparison_results_model = cls(
            table_comparison_results=table_comparison_results,
            column_comparison_results=column_comparison_results,
        )

        table_comparison_results_model.additional_properties = d
        return table_comparison_results_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.column_monitoring_check_categories_spec import (
        ColumnMonitoringCheckCategoriesSpec,
    )
    from ..models.column_partitioned_check_categories_spec import (
        ColumnPartitionedCheckCategoriesSpec,
    )
    from ..models.column_profiling_check_categories_spec import (
        ColumnProfilingCheckCategoriesSpec,
    )
    from ..models.target_column_pattern_spec import TargetColumnPatternSpec


T = TypeVar("T", bound="ColumnQualityPolicySpec")


@_attrs_define
class ColumnQualityPolicySpec:
    """
    Attributes:
        priority (Union[Unset, int]): The priority of the pattern. Patterns with lower values are applied before
            patterns with higher priority values.
        disabled (Union[Unset, bool]): Disables this data quality check configuration. The checks will not be activated.
        description (Union[Unset, str]): The description (documentation) of this data quality check configuration.
        target (Union[Unset, TargetColumnPatternSpec]):
        profiling_checks (Union[Unset, ColumnProfilingCheckCategoriesSpec]):
        monitoring_checks (Union[Unset, ColumnMonitoringCheckCategoriesSpec]):
        partitioned_checks (Union[Unset, ColumnPartitionedCheckCategoriesSpec]):
    """

    priority: Union[Unset, int] = UNSET
    disabled: Union[Unset, bool] = UNSET
    description: Union[Unset, str] = UNSET
    target: Union[Unset, "TargetColumnPatternSpec"] = UNSET
    profiling_checks: Union[Unset, "ColumnProfilingCheckCategoriesSpec"] = UNSET
    monitoring_checks: Union[Unset, "ColumnMonitoringCheckCategoriesSpec"] = UNSET
    partitioned_checks: Union[Unset, "ColumnPartitionedCheckCategoriesSpec"] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        priority = self.priority
        disabled = self.disabled
        description = self.description
        target: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.target, Unset):
            target = self.target.to_dict()

        profiling_checks: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profiling_checks, Unset):
            profiling_checks = self.profiling_checks.to_dict()

        monitoring_checks: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monitoring_checks, Unset):
            monitoring_checks = self.monitoring_checks.to_dict()

        partitioned_checks: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.partitioned_checks, Unset):
            partitioned_checks = self.partitioned_checks.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if priority is not UNSET:
            field_dict["priority"] = priority
        if disabled is not UNSET:
            field_dict["disabled"] = disabled
        if description is not UNSET:
            field_dict["description"] = description
        if target is not UNSET:
            field_dict["target"] = target
        if profiling_checks is not UNSET:
            field_dict["profiling_checks"] = profiling_checks
        if monitoring_checks is not UNSET:
            field_dict["monitoring_checks"] = monitoring_checks
        if partitioned_checks is not UNSET:
            field_dict["partitioned_checks"] = partitioned_checks

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.column_monitoring_check_categories_spec import (
            ColumnMonitoringCheckCategoriesSpec,
        )
        from ..models.column_partitioned_check_categories_spec import (
            ColumnPartitionedCheckCategoriesSpec,
        )
        from ..models.column_profiling_check_categories_spec import (
            ColumnProfilingCheckCategoriesSpec,
        )
        from ..models.target_column_pattern_spec import TargetColumnPatternSpec

        d = src_dict.copy()
        priority = d.pop("priority", UNSET)

        disabled = d.pop("disabled", UNSET)

        description = d.pop("description", UNSET)

        _target = d.pop("target", UNSET)
        target: Union[Unset, TargetColumnPatternSpec]
        if isinstance(_target, Unset):
            target = UNSET
        else:
            target = TargetColumnPatternSpec.from_dict(_target)

        _profiling_checks = d.pop("profiling_checks", UNSET)
        profiling_checks: Union[Unset, ColumnProfilingCheckCategoriesSpec]
        if isinstance(_profiling_checks, Unset):
            profiling_checks = UNSET
        else:
            profiling_checks = ColumnProfilingCheckCategoriesSpec.from_dict(
                _profiling_checks
            )

        _monitoring_checks = d.pop("monitoring_checks", UNSET)
        monitoring_checks: Union[Unset, ColumnMonitoringCheckCategoriesSpec]
        if isinstance(_monitoring_checks, Unset):
            monitoring_checks = UNSET
        else:
            monitoring_checks = ColumnMonitoringCheckCategoriesSpec.from_dict(
                _monitoring_checks
            )

        _partitioned_checks = d.pop("partitioned_checks", UNSET)
        partitioned_checks: Union[Unset, ColumnPartitionedCheckCategoriesSpec]
        if isinstance(_partitioned_checks, Unset):
            partitioned_checks = UNSET
        else:
            partitioned_checks = ColumnPartitionedCheckCategoriesSpec.from_dict(
                _partitioned_checks
            )

        column_quality_policy_spec = cls(
            priority=priority,
            disabled=disabled,
            description=description,
            target=target,
            profiling_checks=profiling_checks,
            monitoring_checks=monitoring_checks,
            partitioned_checks=partitioned_checks,
        )

        column_quality_policy_spec.additional_properties = d
        return column_quality_policy_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="DataDictionaryListModel")


@_attrs_define
class DataDictionaryListModel:
    """Data dictionary CSV file list model with the basic information about the dictionary.

    Attributes:
        dictionary_name (Union[Unset, str]): Dictionary name. It is the name of a file in the dictionaries/ folder
            inside the DQOps user's home folder.
        can_edit (Union[Unset, bool]): Boolean flag that decides if the current user can update or delete the dictionary
            file.
        can_access_dictionary (Union[Unset, bool]): Boolean flag that decides if the current user see or download the
            dictionary file.
    """

    dictionary_name: Union[Unset, str] = UNSET
    can_edit: Union[Unset, bool] = UNSET
    can_access_dictionary: Union[Unset, bool] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        dictionary_name = self.dictionary_name
        can_edit = self.can_edit
        can_access_dictionary = self.can_access_dictionary

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if dictionary_name is not UNSET:
            field_dict["dictionary_name"] = dictionary_name
        if can_edit is not UNSET:
            field_dict["can_edit"] = can_edit
        if can_access_dictionary is not UNSET:
            field_dict["can_access_dictionary"] = can_access_dictionary

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        dictionary_name = d.pop("dictionary_name", UNSET)

        can_edit = d.pop("can_edit", UNSET)

        can_access_dictionary = d.pop("can_access_dictionary", UNSET)

        data_dictionary_list_model = cls(
            dictionary_name=dictionary_name,
            can_edit=can_edit,
            can_access_dictionary=can_access_dictionary,
        )

        data_dictionary_list_model.additional_properties = d
        return data_dictionary_list_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.compression_type import CompressionType
from ..types import UNSET, Unset

T = TypeVar("T", bound="ParquetFileFormatSpec")


@_attrs_define
class ParquetFileFormatSpec:
    """
    Attributes:
        binary_as_string (Union[Unset, bool]): Parquet files generated by legacy writers do not correctly set the UTF8
            flag for strings, causing string columns to be loaded as BLOB instead. Set this to true to load binary columns
            as strings.
        filename (Union[Unset, bool]): Whether or not an extra filename column should be included in the result.
        file_row_number (Union[Unset, bool]): Whether or not to include the file_row_number column.
        hive_partitioning (Union[Unset, bool]): Whether or not to interpret the path as a hive partitioned path.
        union_by_name (Union[Unset, bool]): Whether the columns of multiple schemas should be unified by name, rather
            than by position.
        compression (Union[Unset, CompressionType]):
        no_compression_extension (Union[Unset, bool]): Whether the compression extension is present at the end of the
            file name.
        file_extension (Union[Unset, str]): Specifies a custom file name extension. The default is ".parquet".
    """

    binary_as_string: Union[Unset, bool] = UNSET
    filename: Union[Unset, bool] = UNSET
    file_row_number: Union[Unset, bool] = UNSET
    hive_partitioning: Union[Unset, bool] = UNSET
    union_by_name: Union[Unset, bool] = UNSET
    compression: Union[Unset, CompressionType] = UNSET
    no_compression_extension: Union[Unset, bool] = UNSET
    file_extension: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        binary_as_string = self.binary_as_string
        filename = self.filename
        file_row_number = self.file_row_number
        hive_partitioning = self.hive_partitioning
        union_by_name = self.union_by_name
        compression: Union[Unset, str] = UNSET
        if not isinstance(self.compression, Unset):
            compression = self.compression.value

        no_compression_extension = self.no_compression_extension
        file_extension = self.file_extension

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if binary_as_string is not UNSET:
            field_dict["binary_as_string"] = binary_as_string
        if filename is not UNSET:
            field_dict["filename"] = filename
        if file_row_number is not UNSET:
            field_dict["file_row_number"] = file_row_number
        if hive_partitioning is not UNSET:
            field_dict["hive_partitioning"] = hive_partitioning
        if union_by_name is not UNSET:
            field_dict["union_by_name"] = union_by_name
        if compression is not UNSET:
            field_dict["compression"] = compression
        if no_compression_extension is not UNSET:
            field_dict["no_compression_extension"] = no_compression_extension
        if file_extension is not UNSET:
            field_dict["file_extension"] = file_extension

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        binary_as_string = d.pop("binary_as_string", UNSET)

        filename = d.pop("filename", UNSET)

        file_row_number = d.pop("file_row_number", UNSET)

        hive_partitioning = d.pop("hive_partitioning", UNSET)

        union_by_name = d.pop("union_by_name", UNSET)

        _compression = d.pop("compression", UNSET)
        compression: Union[Unset, CompressionType]
        if isinstance(_compression, Unset):
            compression = UNSET
        else:
            compression = CompressionType(_compression)

        no_compression_extension = d.pop("no_compression_extension", UNSET)

        file_extension = d.pop("file_extension", UNSET)

        parquet_file_format_spec = cls(
            binary_as_string=binary_as_string,
            filename=filename,
            file_row_number=file_row_number,
            hive_partitioning=hive_partitioning,
            union_by_name=union_by_name,
            compression=compression,
            no_compression_extension=no_compression_extension,
            file_extension=file_extension,
        )

        parquet_file_format_spec.additional_properties = d
        return parquet_file_format_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.avro_file_format_spec import AvroFileFormatSpec
    from ..models.csv_file_format_spec import CsvFileFormatSpec
    from ..models.delta_lake_file_format_spec import DeltaLakeFileFormatSpec
    from ..models.iceberg_file_format_spec import IcebergFileFormatSpec
    from ..models.json_file_format_spec import JsonFileFormatSpec
    from ..models.parquet_file_format_spec import ParquetFileFormatSpec


T = TypeVar("T", bound="FileFormatSpec")


@_attrs_define
class FileFormatSpec:
    """
    Attributes:
        csv (Union[Unset, CsvFileFormatSpec]):
        json (Union[Unset, JsonFileFormatSpec]):
        parquet (Union[Unset, ParquetFileFormatSpec]):
        avro (Union[Unset, AvroFileFormatSpec]):
        iceberg (Union[Unset, IcebergFileFormatSpec]):
        delta_lake (Union[Unset, DeltaLakeFileFormatSpec]):
        file_paths (Union[Unset, List[str]]): The list of paths to files with data that are used as a source.
    """

    csv: Union[Unset, "CsvFileFormatSpec"] = UNSET
    json: Union[Unset, "JsonFileFormatSpec"] = UNSET
    parquet: Union[Unset, "ParquetFileFormatSpec"] = UNSET
    avro: Union[Unset, "AvroFileFormatSpec"] = UNSET
    iceberg: Union[Unset, "IcebergFileFormatSpec"] = UNSET
    delta_lake: Union[Unset, "DeltaLakeFileFormatSpec"] = UNSET
    file_paths: Union[Unset, List[str]] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        csv: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.csv, Unset):
            csv = self.csv.to_dict()

        json: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.json, Unset):
            json = self.json.to_dict()

        parquet: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.parquet, Unset):
            parquet = self.parquet.to_dict()

        avro: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.avro, Unset):
            avro = self.avro.to_dict()

        iceberg: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.iceberg, Unset):
            iceberg = self.iceberg.to_dict()

        delta_lake: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.delta_lake, Unset):
            delta_lake = self.delta_lake.to_dict()

        file_paths: Union[Unset, List[str]] = UNSET
        if not isinstance(self.file_paths, Unset):
            file_paths = self.file_paths

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if csv is not UNSET:
            field_dict["csv"] = csv
        if json is not UNSET:
            field_dict["json"] = json
        if parquet is not UNSET:
            field_dict["parquet"] = parquet
        if avro is not UNSET:
            field_dict["avro"] = avro
        if iceberg is not UNSET:
            field_dict["iceberg"] = iceberg
        if delta_lake is not UNSET:
            field_dict["delta_lake"] = delta_lake
        if file_paths is not UNSET:
            field_dict["file_paths"] = file_paths

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.avro_file_format_spec import AvroFileFormatSpec
        from ..models.csv_file_format_spec import CsvFileFormatSpec
        from ..models.delta_lake_file_format_spec import DeltaLakeFileFormatSpec
        from ..models.iceberg_file_format_spec import IcebergFileFormatSpec
        from ..models.json_file_format_spec import JsonFileFormatSpec
        from ..models.parquet_file_format_spec import ParquetFileFormatSpec

        d = src_dict.copy()
        _csv = d.pop("csv", UNSET)
        csv: Union[Unset, CsvFileFormatSpec]
        if isinstance(_csv, Unset):
            csv = UNSET
        else:
            csv = CsvFileFormatSpec.from_dict(_csv)

        _json = d.pop("json", UNSET)
        json: Union[Unset, JsonFileFormatSpec]
        if isinstance(_json, Unset):
            json = UNSET
        else:
            json = JsonFileFormatSpec.from_dict(_json)

        _parquet = d.pop("parquet", UNSET)
        parquet: Union[Unset, ParquetFileFormatSpec]
        if isinstance(_parquet, Unset):
            parquet = UNSET
        else:
            parquet = ParquetFileFormatSpec.from_dict(_parquet)

        _avro = d.pop("avro", UNSET)
        avro: Union[Unset, AvroFileFormatSpec]
        if isinstance(_avro, Unset):
            avro = UNSET
        else:
            avro = AvroFileFormatSpec.from_dict(_avro)

        _iceberg = d.pop("iceberg", UNSET)
        iceberg: Union[Unset, IcebergFileFormatSpec]
        if isinstance(_iceberg, Unset):
            iceberg = UNSET
        else:
            iceberg = IcebergFileFormatSpec.from_dict(_iceberg)

        _delta_lake = d.pop("delta_lake", UNSET)
        delta_lake: Union[Unset, DeltaLakeFileFormatSpec]
        if isinstance(_delta_lake, Unset):
            delta_lake = UNSET
        else:
            delta_lake = DeltaLakeFileFormatSpec.from_dict(_delta_lake)

        file_paths = cast(List[str], d.pop("file_paths", UNSET))

        file_format_spec = cls(
            csv=csv,
            json=json,
            parquet=parquet,
            avro=avro,
            iceberg=iceberg,
            delta_lake=delta_lake,
            file_paths=file_paths,
        )

        file_format_spec.additional_properties = d
        return file_format_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.table_accuracy_daily_monitoring_checks_spec import (
        TableAccuracyDailyMonitoringChecksSpec,
    )
    from ..models.table_availability_daily_monitoring_checks_spec import (
        TableAvailabilityDailyMonitoringChecksSpec,
    )
    from ..models.table_custom_sql_daily_monitoring_checks_spec import (
        TableCustomSqlDailyMonitoringChecksSpec,
    )
    from ..models.table_daily_monitoring_check_categories_spec_comparisons import (
        TableDailyMonitoringCheckCategoriesSpecComparisons,
    )
    from ..models.table_daily_monitoring_check_categories_spec_custom import (
        TableDailyMonitoringCheckCategoriesSpecCustom,
    )
    from ..models.table_schema_daily_monitoring_checks_spec import (
        TableSchemaDailyMonitoringChecksSpec,
    )
    from ..models.table_timeliness_daily_monitoring_checks_spec import (
        TableTimelinessDailyMonitoringChecksSpec,
    )
    from ..models.table_uniqueness_daily_monitoring_checks_spec import (
        TableUniquenessDailyMonitoringChecksSpec,
    )
    from ..models.table_volume_daily_monitoring_checks_spec import (
        TableVolumeDailyMonitoringChecksSpec,
    )


T = TypeVar("T", bound="TableDailyMonitoringCheckCategoriesSpec")


@_attrs_define
class TableDailyMonitoringCheckCategoriesSpec:
    """
    Attributes:
        custom (Union[Unset, TableDailyMonitoringCheckCategoriesSpecCustom]): Dictionary of custom checks. The keys are
            check names within this category.
        volume (Union[Unset, TableVolumeDailyMonitoringChecksSpec]):
        timeliness (Union[Unset, TableTimelinessDailyMonitoringChecksSpec]):
        accuracy (Union[Unset, TableAccuracyDailyMonitoringChecksSpec]):
        custom_sql (Union[Unset, TableCustomSqlDailyMonitoringChecksSpec]):
        availability (Union[Unset, TableAvailabilityDailyMonitoringChecksSpec]):
        schema (Union[Unset, TableSchemaDailyMonitoringChecksSpec]):
        uniqueness (Union[Unset, TableUniquenessDailyMonitoringChecksSpec]):
        comparisons (Union[Unset, TableDailyMonitoringCheckCategoriesSpecComparisons]): Dictionary of configuration of
            checks for table comparisons. The key that identifies each comparison must match the name of a data comparison
            that is configured on the parent table.
    """

    custom: Union[Unset, "TableDailyMonitoringCheckCategoriesSpecCustom"] = UNSET
    volume: Union[Unset, "TableVolumeDailyMonitoringChecksSpec"] = UNSET
    timeliness: Union[Unset, "TableTimelinessDailyMonitoringChecksSpec"] = UNSET
    accuracy: Union[Unset, "TableAccuracyDailyMonitoringChecksSpec"] = UNSET
    custom_sql: Union[Unset, "TableCustomSqlDailyMonitoringChecksSpec"] = UNSET
    availability: Union[Unset, "TableAvailabilityDailyMonitoringChecksSpec"] = UNSET
    schema: Union[Unset, "TableSchemaDailyMonitoringChecksSpec"] = UNSET
    uniqueness: Union[Unset, "TableUniquenessDailyMonitoringChecksSpec"] = UNSET
    comparisons: Union[Unset, "TableDailyMonitoringCheckCategoriesSpecComparisons"] = (
        UNSET
    )
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        custom: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.custom, Unset):
            custom = self.custom.to_dict()

        volume: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.volume, Unset):
            volume = self.volume.to_dict()

        timeliness: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.timeliness, Unset):
            timeliness = self.timeliness.to_dict()

        accuracy: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.accuracy, Unset):
            accuracy = self.accuracy.to_dict()

        custom_sql: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.custom_sql, Unset):
            custom_sql = self.custom_sql.to_dict()

        availability: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.availability, Unset):
            availability = self.availability.to_dict()

        schema: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.schema, Unset):
            schema = self.schema.to_dict()

        uniqueness: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.uniqueness, Unset):
            uniqueness = self.uniqueness.to_dict()

        comparisons: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.comparisons, Unset):
            comparisons = self.comparisons.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if custom is not UNSET:
            field_dict["custom"] = custom
        if volume is not UNSET:
            field_dict["volume"] = volume
        if timeliness is not UNSET:
            field_dict["timeliness"] = timeliness
        if accuracy is not UNSET:
            field_dict["accuracy"] = accuracy
        if custom_sql is not UNSET:
            field_dict["custom_sql"] = custom_sql
        if availability is not UNSET:
            field_dict["availability"] = availability
        if schema is not UNSET:
            field_dict["schema"] = schema
        if uniqueness is not UNSET:
            field_dict["uniqueness"] = uniqueness
        if comparisons is not UNSET:
            field_dict["comparisons"] = comparisons

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.table_accuracy_daily_monitoring_checks_spec import (
            TableAccuracyDailyMonitoringChecksSpec,
        )
        from ..models.table_availability_daily_monitoring_checks_spec import (
            TableAvailabilityDailyMonitoringChecksSpec,
        )
        from ..models.table_custom_sql_daily_monitoring_checks_spec import (
            TableCustomSqlDailyMonitoringChecksSpec,
        )
        from ..models.table_daily_monitoring_check_categories_spec_comparisons import (
            TableDailyMonitoringCheckCategoriesSpecComparisons,
        )
        from ..models.table_daily_monitoring_check_categories_spec_custom import (
            TableDailyMonitoringCheckCategoriesSpecCustom,
        )
        from ..models.table_schema_daily_monitoring_checks_spec import (
            TableSchemaDailyMonitoringChecksSpec,
        )
        from ..models.table_timeliness_daily_monitoring_checks_spec import (
            TableTimelinessDailyMonitoringChecksSpec,
        )
        from ..models.table_uniqueness_daily_monitoring_checks_spec import (
            TableUniquenessDailyMonitoringChecksSpec,
        )
        from ..models.table_volume_daily_monitoring_checks_spec import (
            TableVolumeDailyMonitoringChecksSpec,
        )

        d = src_dict.copy()
        _custom = d.pop("custom", UNSET)
        custom: Union[Unset, TableDailyMonitoringCheckCategoriesSpecCustom]
        if isinstance(_custom, Unset):
            custom = UNSET
        else:
            custom = TableDailyMonitoringCheckCategoriesSpecCustom.from_dict(_custom)

        _volume = d.pop("volume", UNSET)
        volume: Union[Unset, TableVolumeDailyMonitoringChecksSpec]
        if isinstance(_volume, Unset):
            volume = UNSET
        else:
            volume = TableVolumeDailyMonitoringChecksSpec.from_dict(_volume)

        _timeliness = d.pop("timeliness", UNSET)
        timeliness: Union[Unset, TableTimelinessDailyMonitoringChecksSpec]
        if isinstance(_timeliness, Unset):
            timeliness = UNSET
        else:
            timeliness = TableTimelinessDailyMonitoringChecksSpec.from_dict(_timeliness)

        _accuracy = d.pop("accuracy", UNSET)
        accuracy: Union[Unset, TableAccuracyDailyMonitoringChecksSpec]
        if isinstance(_accuracy, Unset):
            accuracy = UNSET
        else:
            accuracy = TableAccuracyDailyMonitoringChecksSpec.from_dict(_accuracy)

        _custom_sql = d.pop("custom_sql", UNSET)
        custom_sql: Union[Unset, TableCustomSqlDailyMonitoringChecksSpec]
        if isinstance(_custom_sql, Unset):
            custom_sql = UNSET
        else:
            custom_sql = TableCustomSqlDailyMonitoringChecksSpec.from_dict(_custom_sql)

        _availability = d.pop("availability", UNSET)
        availability: Union[Unset, TableAvailabilityDailyMonitoringChecksSpec]
        if isinstance(_availability, Unset):
            availability = UNSET
        else:
            availability = TableAvailabilityDailyMonitoringChecksSpec.from_dict(
                _availability
            )

        _schema = d.pop("schema", UNSET)
        schema: Union[Unset, TableSchemaDailyMonitoringChecksSpec]
        if isinstance(_schema, Unset):
            schema = UNSET
        else:
            schema = TableSchemaDailyMonitoringChecksSpec.from_dict(_schema)

        _uniqueness = d.pop("uniqueness", UNSET)
        uniqueness: Union[Unset, TableUniquenessDailyMonitoringChecksSpec]
        if isinstance(_uniqueness, Unset):
            uniqueness = UNSET
        else:
            uniqueness = TableUniquenessDailyMonitoringChecksSpec.from_dict(_uniqueness)

        _comparisons = d.pop("comparisons", UNSET)
        comparisons: Union[Unset, TableDailyMonitoringCheckCategoriesSpecComparisons]
        if isinstance(_comparisons, Unset):
            comparisons = UNSET
        else:
            comparisons = TableDailyMonitoringCheckCategoriesSpecComparisons.from_dict(
                _comparisons
            )

        table_daily_monitoring_check_categories_spec = cls(
            custom=custom,
            volume=volume,
            timeliness=timeliness,
            accuracy=accuracy,
            custom_sql=custom_sql,
            availability=availability,
            schema=schema,
            uniqueness=uniqueness,
            comparisons=comparisons,
        )

        table_daily_monitoring_check_categories_spec.additional_properties = d
        return table_daily_monitoring_check_categories_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="CompareThresholdsModel")


@_attrs_define
class CompareThresholdsModel:
    """Model with the compare threshold levels for raising data quality issues at different severity levels when the
    difference between the compared (tested) table and the reference table (the source of truth) exceed given thresholds
    as a percentage of difference between the actual value and the expected value from the reference table.

        Attributes:
            warning_difference_percent (Union[Unset, float]): The percentage difference between the measure value on the
                compared table and the reference table that raises a warning severity data quality issue when the difference is
                bigger.
            error_difference_percent (Union[Unset, float]): The percentage difference between the measure value on the
                compared table and the reference table that raises an error severity data quality issue when the difference is
                bigger.
            fatal_difference_percent (Union[Unset, float]): The percentage difference between the measure value on the
                compared table and the reference table that raises a fatal severity data quality issue when the difference is
                bigger.
    """

    warning_difference_percent: Union[Unset, float] = UNSET
    error_difference_percent: Union[Unset, float] = UNSET
    fatal_difference_percent: Union[Unset, float] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        warning_difference_percent = self.warning_difference_percent
        error_difference_percent = self.error_difference_percent
        fatal_difference_percent = self.fatal_difference_percent

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if warning_difference_percent is not UNSET:
            field_dict["warning_difference_percent"] = warning_difference_percent
        if error_difference_percent is not UNSET:
            field_dict["error_difference_percent"] = error_difference_percent
        if fatal_difference_percent is not UNSET:
            field_dict["fatal_difference_percent"] = fatal_difference_percent

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        warning_difference_percent = d.pop("warning_difference_percent", UNSET)

        error_difference_percent = d.pop("error_difference_percent", UNSET)

        fatal_difference_percent = d.pop("fatal_difference_percent", UNSET)

        compare_thresholds_model = cls(
            warning_difference_percent=warning_difference_percent,
            error_difference_percent=error_difference_percent,
            fatal_difference_percent=fatal_difference_percent,
        )

        compare_thresholds_model.additional_properties = d
        return compare_thresholds_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="DataDeleteResultPartition")


@_attrs_define
class DataDeleteResultPartition:
    """
    Attributes:
        rows_affected_count (Union[Unset, int]): The number of rows that were deleted from the partition.
        partition_deleted (Union[Unset, bool]): True if a whole partition (a parquet file) was deleted instead of
            removing only selected rows.
    """

    rows_affected_count: Union[Unset, int] = UNSET
    partition_deleted: Union[Unset, bool] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        rows_affected_count = self.rows_affected_count
        partition_deleted = self.partition_deleted

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if rows_affected_count is not UNSET:
            field_dict["rowsAffectedCount"] = rows_affected_count
        if partition_deleted is not UNSET:
            field_dict["partitionDeleted"] = partition_deleted

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        rows_affected_count = d.pop("rowsAffectedCount", UNSET)

        partition_deleted = d.pop("partitionDeleted", UNSET)

        data_delete_result_partition = cls(
            rows_affected_count=rows_affected_count,
            partition_deleted=partition_deleted,
        )

        data_delete_result_partition.additional_properties = d
        return data_delete_result_partition

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.profiling_time_period_truncation import ProfilingTimePeriodTruncation
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.table_accuracy_profiling_checks_spec import (
        TableAccuracyProfilingChecksSpec,
    )
    from ..models.table_availability_profiling_checks_spec import (
        TableAvailabilityProfilingChecksSpec,
    )
    from ..models.table_custom_sql_profiling_checks_spec import (
        TableCustomSqlProfilingChecksSpec,
    )
    from ..models.table_profiling_check_categories_spec_comparisons import (
        TableProfilingCheckCategoriesSpecComparisons,
    )
    from ..models.table_profiling_check_categories_spec_custom import (
        TableProfilingCheckCategoriesSpecCustom,
    )
    from ..models.table_schema_profiling_checks_spec import (
        TableSchemaProfilingChecksSpec,
    )
    from ..models.table_timeliness_profiling_checks_spec import (
        TableTimelinessProfilingChecksSpec,
    )
    from ..models.table_uniqueness_profiling_checks_spec import (
        TableUniquenessProfilingChecksSpec,
    )
    from ..models.table_volume_profiling_checks_spec import (
        TableVolumeProfilingChecksSpec,
    )


T = TypeVar("T", bound="TableProfilingCheckCategoriesSpec")


@_attrs_define
class TableProfilingCheckCategoriesSpec:
    """
    Attributes:
        custom (Union[Unset, TableProfilingCheckCategoriesSpecCustom]): Dictionary of custom checks. The keys are check
            names within this category.
        result_truncation (Union[Unset, ProfilingTimePeriodTruncation]):
        volume (Union[Unset, TableVolumeProfilingChecksSpec]):
        timeliness (Union[Unset, TableTimelinessProfilingChecksSpec]):
        accuracy (Union[Unset, TableAccuracyProfilingChecksSpec]):
        custom_sql (Union[Unset, TableCustomSqlProfilingChecksSpec]):
        availability (Union[Unset, TableAvailabilityProfilingChecksSpec]):
        schema (Union[Unset, TableSchemaProfilingChecksSpec]):
        uniqueness (Union[Unset, TableUniquenessProfilingChecksSpec]):
        comparisons (Union[Unset, TableProfilingCheckCategoriesSpecComparisons]): Dictionary of configuration of checks
            for table comparisons. The key that identifies each comparison must match the name of a data comparison that is
            configured on the parent table.
    """

    custom: Union[Unset, "TableProfilingCheckCategoriesSpecCustom"] = UNSET
    result_truncation: Union[Unset, ProfilingTimePeriodTruncation] = UNSET
    volume: Union[Unset, "TableVolumeProfilingChecksSpec"] = UNSET
    timeliness: Union[Unset, "TableTimelinessProfilingChecksSpec"] = UNSET
    accuracy: Union[Unset, "TableAccuracyProfilingChecksSpec"] = UNSET
    custom_sql: Union[Unset, "TableCustomSqlProfilingChecksSpec"] = UNSET
    availability: Union[Unset, "TableAvailabilityProfilingChecksSpec"] = UNSET
    schema: Union[Unset, "TableSchemaProfilingChecksSpec"] = UNSET
    uniqueness: Union[Unset, "TableUniquenessProfilingChecksSpec"] = UNSET
    comparisons: Union[Unset, "TableProfilingCheckCategoriesSpecComparisons"] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        custom: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.custom, Unset):
            custom = self.custom.to_dict()

        result_truncation: Union[Unset, str] = UNSET
        if not isinstance(self.result_truncation, Unset):
            result_truncation = self.result_truncation.value

        volume: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.volume, Unset):
            volume = self.volume.to_dict()

        timeliness: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.timeliness, Unset):
            timeliness = self.timeliness.to_dict()

        accuracy: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.accuracy, Unset):
            accuracy = self.accuracy.to_dict()

        custom_sql: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.custom_sql, Unset):
            custom_sql = self.custom_sql.to_dict()

        availability: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.availability, Unset):
            availability = self.availability.to_dict()

        schema: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.schema, Unset):
            schema = self.schema.to_dict()

        uniqueness: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.uniqueness, Unset):
            uniqueness = self.uniqueness.to_dict()

        comparisons: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.comparisons, Unset):
            comparisons = self.comparisons.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if custom is not UNSET:
            field_dict["custom"] = custom
        if result_truncation is not UNSET:
            field_dict["result_truncation"] = result_truncation
        if volume is not UNSET:
            field_dict["volume"] = volume
        if timeliness is not UNSET:
            field_dict["timeliness"] = timeliness
        if accuracy is not UNSET:
            field_dict["accuracy"] = accuracy
        if custom_sql is not UNSET:
            field_dict["custom_sql"] = custom_sql
        if availability is not UNSET:
            field_dict["availability"] = availability
        if schema is not UNSET:
            field_dict["schema"] = schema
        if uniqueness is not UNSET:
            field_dict["uniqueness"] = uniqueness
        if comparisons is not UNSET:
            field_dict["comparisons"] = comparisons

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.table_accuracy_profiling_checks_spec import (
            TableAccuracyProfilingChecksSpec,
        )
        from ..models.table_availability_profiling_checks_spec import (
            TableAvailabilityProfilingChecksSpec,
        )
        from ..models.table_custom_sql_profiling_checks_spec import (
            TableCustomSqlProfilingChecksSpec,
        )
        from ..models.table_profiling_check_categories_spec_comparisons import (
            TableProfilingCheckCategoriesSpecComparisons,
        )
        from ..models.table_profiling_check_categories_spec_custom import (
            TableProfilingCheckCategoriesSpecCustom,
        )
        from ..models.table_schema_profiling_checks_spec import (
            TableSchemaProfilingChecksSpec,
        )
        from ..models.table_timeliness_profiling_checks_spec import (
            TableTimelinessProfilingChecksSpec,
        )
        from ..models.table_uniqueness_profiling_checks_spec import (
            TableUniquenessProfilingChecksSpec,
        )
        from ..models.table_volume_profiling_checks_spec import (
            TableVolumeProfilingChecksSpec,
        )

        d = src_dict.copy()
        _custom = d.pop("custom", UNSET)
        custom: Union[Unset, TableProfilingCheckCategoriesSpecCustom]
        if isinstance(_custom, Unset):
            custom = UNSET
        else:
            custom = TableProfilingCheckCategoriesSpecCustom.from_dict(_custom)

        _result_truncation = d.pop("result_truncation", UNSET)
        result_truncation: Union[Unset, ProfilingTimePeriodTruncation]
        if isinstance(_result_truncation, Unset):
            result_truncation = UNSET
        else:
            result_truncation = ProfilingTimePeriodTruncation(_result_truncation)

        _volume = d.pop("volume", UNSET)
        volume: Union[Unset, TableVolumeProfilingChecksSpec]
        if isinstance(_volume, Unset):
            volume = UNSET
        else:
            volume = TableVolumeProfilingChecksSpec.from_dict(_volume)

        _timeliness = d.pop("timeliness", UNSET)
        timeliness: Union[Unset, TableTimelinessProfilingChecksSpec]
        if isinstance(_timeliness, Unset):
            timeliness = UNSET
        else:
            timeliness = TableTimelinessProfilingChecksSpec.from_dict(_timeliness)

        _accuracy = d.pop("accuracy", UNSET)
        accuracy: Union[Unset, TableAccuracyProfilingChecksSpec]
        if isinstance(_accuracy, Unset):
            accuracy = UNSET
        else:
            accuracy = TableAccuracyProfilingChecksSpec.from_dict(_accuracy)

        _custom_sql = d.pop("custom_sql", UNSET)
        custom_sql: Union[Unset, TableCustomSqlProfilingChecksSpec]
        if isinstance(_custom_sql, Unset):
            custom_sql = UNSET
        else:
            custom_sql = TableCustomSqlProfilingChecksSpec.from_dict(_custom_sql)

        _availability = d.pop("availability", UNSET)
        availability: Union[Unset, TableAvailabilityProfilingChecksSpec]
        if isinstance(_availability, Unset):
            availability = UNSET
        else:
            availability = TableAvailabilityProfilingChecksSpec.from_dict(_availability)

        _schema = d.pop("schema", UNSET)
        schema: Union[Unset, TableSchemaProfilingChecksSpec]
        if isinstance(_schema, Unset):
            schema = UNSET
        else:
            schema = TableSchemaProfilingChecksSpec.from_dict(_schema)

        _uniqueness = d.pop("uniqueness", UNSET)
        uniqueness: Union[Unset, TableUniquenessProfilingChecksSpec]
        if isinstance(_uniqueness, Unset):
            uniqueness = UNSET
        else:
            uniqueness = TableUniquenessProfilingChecksSpec.from_dict(_uniqueness)

        _comparisons = d.pop("comparisons", UNSET)
        comparisons: Union[Unset, TableProfilingCheckCategoriesSpecComparisons]
        if isinstance(_comparisons, Unset):
            comparisons = UNSET
        else:
            comparisons = TableProfilingCheckCategoriesSpecComparisons.from_dict(
                _comparisons
            )

        table_profiling_check_categories_spec = cls(
            custom=custom,
            result_truncation=result_truncation,
            volume=volume,
            timeliness=timeliness,
            accuracy=accuracy,
            custom_sql=custom_sql,
            availability=availability,
            schema=schema,
            uniqueness=uniqueness,
            comparisons=comparisons,
        )

        table_profiling_check_categories_spec.additional_properties = d
        return table_profiling_check_categories_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.teradata_parameters_spec_properties import (
        TeradataParametersSpecProperties,
    )


T = TypeVar("T", bound="TeradataParametersSpec")


@_attrs_define
class TeradataParametersSpec:
    """
    Attributes:
        host (Union[Unset, str]): Teradata host name. Supports also a ${TERADATA_HOST} configuration with a custom
            environment variable.
        port (Union[Unset, str]): Teradata port number. The default port is 1025. Supports also a ${TERADATA_PORT}
            configuration with a custom environment variable.
        user (Union[Unset, str]): Teradata user name. The value can be in the ${ENVIRONMENT_VARIABLE_NAME} format to use
            dynamic substitution.
        password (Union[Unset, str]): Teradata database password. The value can be in the ${ENVIRONMENT_VARIABLE_NAME}
            format to use dynamic substitution.
        properties (Union[Unset, TeradataParametersSpecProperties]): A dictionary of custom JDBC parameters that are
            added to the JDBC connection string, a key/value dictionary.
        database (Union[Unset, str]):
    """

    host: Union[Unset, str] = UNSET
    port: Union[Unset, str] = UNSET
    user: Union[Unset, str] = UNSET
    password: Union[Unset, str] = UNSET
    properties: Union[Unset, "TeradataParametersSpecProperties"] = UNSET
    database: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        host = self.host
        port = self.port
        user = self.user
        password = self.password
        properties: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.properties, Unset):
            properties = self.properties.to_dict()

        database = self.database

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if host is not UNSET:
            field_dict["host"] = host
        if port is not UNSET:
            field_dict["port"] = port
        if user is not UNSET:
            field_dict["user"] = user
        if password is not UNSET:
            field_dict["password"] = password
        if properties is not UNSET:
            field_dict["properties"] = properties
        if database is not UNSET:
            field_dict["database"] = database

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.teradata_parameters_spec_properties import (
            TeradataParametersSpecProperties,
        )

        d = src_dict.copy()
        host = d.pop("host", UNSET)

        port = d.pop("port", UNSET)

        user = d.pop("user", UNSET)

        password = d.pop("password", UNSET)

        _properties = d.pop("properties", UNSET)
        properties: Union[Unset, TeradataParametersSpecProperties]
        if isinstance(_properties, Unset):
            properties = UNSET
        else:
            properties = TeradataParametersSpecProperties.from_dict(_properties)

        database = d.pop("database", UNSET)

        teradata_parameters_spec = cls(
            host=host,
            port=port,
            user=user,
            password=password,
            properties=properties,
            database=database,
        )

        teradata_parameters_spec.additional_properties = d
        return teradata_parameters_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.column_custom_sql_monthly_partitioned_checks_spec_custom_checks import (
        ColumnCustomSqlMonthlyPartitionedChecksSpecCustomChecks,
    )
    from ..models.column_sql_aggregate_expression_check_spec import (
        ColumnSqlAggregateExpressionCheckSpec,
    )
    from ..models.column_sql_condition_failed_check_spec import (
        ColumnSqlConditionFailedCheckSpec,
    )
    from ..models.column_sql_condition_passed_percent_check_spec import (
        ColumnSqlConditionPassedPercentCheckSpec,
    )
    from ..models.column_sql_import_custom_result_check_spec import (
        ColumnSqlImportCustomResultCheckSpec,
    )


T = TypeVar("T", bound="ColumnCustomSqlMonthlyPartitionedChecksSpec")


@_attrs_define
class ColumnCustomSqlMonthlyPartitionedChecksSpec:
    """
    Attributes:
        custom_checks (Union[Unset, ColumnCustomSqlMonthlyPartitionedChecksSpecCustomChecks]): Dictionary of additional
            custom checks within this category. The keys are check names defined in the definition section. The sensor
            parameters and rules should match the type of the configured sensor and rule for the custom check.
        monthly_partition_sql_condition_failed_on_column (Union[Unset, ColumnSqlConditionFailedCheckSpec]):
        monthly_partition_sql_condition_passed_percent_on_column (Union[Unset,
            ColumnSqlConditionPassedPercentCheckSpec]):
        monthly_partition_sql_aggregate_expression_on_column (Union[Unset, ColumnSqlAggregateExpressionCheckSpec]):
        monthly_partition_import_custom_result_on_column (Union[Unset, ColumnSqlImportCustomResultCheckSpec]):
    """

    custom_checks: Union[
        Unset, "ColumnCustomSqlMonthlyPartitionedChecksSpecCustomChecks"
    ] = UNSET
    monthly_partition_sql_condition_failed_on_column: Union[
        Unset, "ColumnSqlConditionFailedCheckSpec"
    ] = UNSET
    monthly_partition_sql_condition_passed_percent_on_column: Union[
        Unset, "ColumnSqlConditionPassedPercentCheckSpec"
    ] = UNSET
    monthly_partition_sql_aggregate_expression_on_column: Union[
        Unset, "ColumnSqlAggregateExpressionCheckSpec"
    ] = UNSET
    monthly_partition_import_custom_result_on_column: Union[
        Unset, "ColumnSqlImportCustomResultCheckSpec"
    ] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        custom_checks: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.custom_checks, Unset):
            custom_checks = self.custom_checks.to_dict()

        monthly_partition_sql_condition_failed_on_column: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(self.monthly_partition_sql_condition_failed_on_column, Unset):
            monthly_partition_sql_condition_failed_on_column = (
                self.monthly_partition_sql_condition_failed_on_column.to_dict()
            )

        monthly_partition_sql_condition_passed_percent_on_column: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(
            self.monthly_partition_sql_condition_passed_percent_on_column, Unset
        ):
            monthly_partition_sql_condition_passed_percent_on_column = (
                self.monthly_partition_sql_condition_passed_percent_on_column.to_dict()
            )

        monthly_partition_sql_aggregate_expression_on_column: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(
            self.monthly_partition_sql_aggregate_expression_on_column, Unset
        ):
            monthly_partition_sql_aggregate_expression_on_column = (
                self.monthly_partition_sql_aggregate_expression_on_column.to_dict()
            )

        monthly_partition_import_custom_result_on_column: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(self.monthly_partition_import_custom_result_on_column, Unset):
            monthly_partition_import_custom_result_on_column = (
                self.monthly_partition_import_custom_result_on_column.to_dict()
            )

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if custom_checks is not UNSET:
            field_dict["custom_checks"] = custom_checks
        if monthly_partition_sql_condition_failed_on_column is not UNSET:
            field_dict["monthly_partition_sql_condition_failed_on_column"] = (
                monthly_partition_sql_condition_failed_on_column
            )
        if monthly_partition_sql_condition_passed_percent_on_column is not UNSET:
            field_dict["monthly_partition_sql_condition_passed_percent_on_column"] = (
                monthly_partition_sql_condition_passed_percent_on_column
            )
        if monthly_partition_sql_aggregate_expression_on_column is not UNSET:
            field_dict["monthly_partition_sql_aggregate_expression_on_column"] = (
                monthly_partition_sql_aggregate_expression_on_column
            )
        if monthly_partition_import_custom_result_on_column is not UNSET:
            field_dict["monthly_partition_import_custom_result_on_column"] = (
                monthly_partition_import_custom_result_on_column
            )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.column_custom_sql_monthly_partitioned_checks_spec_custom_checks import (
            ColumnCustomSqlMonthlyPartitionedChecksSpecCustomChecks,
        )
        from ..models.column_sql_aggregate_expression_check_spec import (
            ColumnSqlAggregateExpressionCheckSpec,
        )
        from ..models.column_sql_condition_failed_check_spec import (
            ColumnSqlConditionFailedCheckSpec,
        )
        from ..models.column_sql_condition_passed_percent_check_spec import (
            ColumnSqlConditionPassedPercentCheckSpec,
        )
        from ..models.column_sql_import_custom_result_check_spec import (
            ColumnSqlImportCustomResultCheckSpec,
        )

        d = src_dict.copy()
        _custom_checks = d.pop("custom_checks", UNSET)
        custom_checks: Union[
            Unset, ColumnCustomSqlMonthlyPartitionedChecksSpecCustomChecks
        ]
        if isinstance(_custom_checks, Unset):
            custom_checks = UNSET
        else:
            custom_checks = (
                ColumnCustomSqlMonthlyPartitionedChecksSpecCustomChecks.from_dict(
                    _custom_checks
                )
            )

        _monthly_partition_sql_condition_failed_on_column = d.pop(
            "monthly_partition_sql_condition_failed_on_column", UNSET
        )
        monthly_partition_sql_condition_failed_on_column: Union[
            Unset, ColumnSqlConditionFailedCheckSpec
        ]
        if isinstance(_monthly_partition_sql_condition_failed_on_column, Unset):
            monthly_partition_sql_condition_failed_on_column = UNSET
        else:
            monthly_partition_sql_condition_failed_on_column = (
                ColumnSqlConditionFailedCheckSpec.from_dict(
                    _monthly_partition_sql_condition_failed_on_column
                )
            )

        _monthly_partition_sql_condition_passed_percent_on_column = d.pop(
            "monthly_partition_sql_condition_passed_percent_on_column", UNSET
        )
        monthly_partition_sql_condition_passed_percent_on_column: Union[
            Unset, ColumnSqlConditionPassedPercentCheckSpec
        ]
        if isinstance(_monthly_partition_sql_condition_passed_percent_on_column, Unset):
            monthly_partition_sql_condition_passed_percent_on_column = UNSET
        else:
            monthly_partition_sql_condition_passed_percent_on_column = (
                ColumnSqlConditionPassedPercentCheckSpec.from_dict(
                    _monthly_partition_sql_condition_passed_percent_on_column
                )
            )

        _monthly_partition_sql_aggregate_expression_on_column = d.pop(
            "monthly_partition_sql_aggregate_expression_on_column", UNSET
        )
        monthly_partition_sql_aggregate_expression_on_column: Union[
            Unset, ColumnSqlAggregateExpressionCheckSpec
        ]
        if isinstance(_monthly_partition_sql_aggregate_expression_on_column, Unset):
            monthly_partition_sql_aggregate_expression_on_column = UNSET
        else:
            monthly_partition_sql_aggregate_expression_on_column = (
                ColumnSqlAggregateExpressionCheckSpec.from_dict(
                    _monthly_partition_sql_aggregate_expression_on_column
                )
            )

        _monthly_partition_import_custom_result_on_column = d.pop(
            "monthly_partition_import_custom_result_on_column", UNSET
        )
        monthly_partition_import_custom_result_on_column: Union[
            Unset, ColumnSqlImportCustomResultCheckSpec
        ]
        if isinstance(_monthly_partition_import_custom_result_on_column, Unset):
            monthly_partition_import_custom_result_on_column = UNSET
        else:
            monthly_partition_import_custom_result_on_column = (
                ColumnSqlImportCustomResultCheckSpec.from_dict(
                    _monthly_partition_import_custom_result_on_column
                )
            )

        column_custom_sql_monthly_partitioned_checks_spec = cls(
            custom_checks=custom_checks,
            monthly_partition_sql_condition_failed_on_column=monthly_partition_sql_condition_failed_on_column,
            monthly_partition_sql_condition_passed_percent_on_column=monthly_partition_sql_condition_passed_percent_on_column,
            monthly_partition_sql_aggregate_expression_on_column=monthly_partition_sql_aggregate_expression_on_column,
            monthly_partition_import_custom_result_on_column=monthly_partition_import_custom_result_on_column,
        )

        column_custom_sql_monthly_partitioned_checks_spec.additional_properties = d
        return column_custom_sql_monthly_partitioned_checks_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.check_container_model import CheckContainerModel
    from ..models.check_mining_proposal_model_column_checks import (
        CheckMiningProposalModelColumnChecks,
    )
    from ..models.check_search_filters import CheckSearchFilters


T = TypeVar("T", bound="CheckMiningProposalModel")


@_attrs_define
class CheckMiningProposalModel:
    """Model that has a proposed configuration of checks on a table and its columns generated by a data quality check
    mining service.

        Attributes:
            missing_current_statistics (Union[Unset, bool]): A boolean flag to inform the caller that the rule mining engine
                failed to propose relevant data quality rules because there are no current statistics. The user should schedule
                a 'collect statistics' job to analyze the table.
            missing_current_profiling_check_results (Union[Unset, bool]): A boolean flag to inform the caller that the rule
                mining engine failed to propose relevant data quality rules because there are no current results from profiling
                checks. The user should run profiling checks to analyze the table.
            table_checks (Union[Unset, CheckContainerModel]): Model that returns the form definition and the form data to
                edit all data quality checks divided by categories.
            column_checks (Union[Unset, CheckMiningProposalModelColumnChecks]): Dictionary of proposed data quality checks
                for each column.
            run_checks_job (Union[Unset, CheckSearchFilters]): Target data quality checks filter, identifies which checks on
                which tables and columns should be executed.
    """

    missing_current_statistics: Union[Unset, bool] = UNSET
    missing_current_profiling_check_results: Union[Unset, bool] = UNSET
    table_checks: Union[Unset, "CheckContainerModel"] = UNSET
    column_checks: Union[Unset, "CheckMiningProposalModelColumnChecks"] = UNSET
    run_checks_job: Union[Unset, "CheckSearchFilters"] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        missing_current_statistics = self.missing_current_statistics
        missing_current_profiling_check_results = (
            self.missing_current_profiling_check_results
        )
        table_checks: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.table_checks, Unset):
            table_checks = self.table_checks.to_dict()

        column_checks: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.column_checks, Unset):
            column_checks = self.column_checks.to_dict()

        run_checks_job: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.run_checks_job, Unset):
            run_checks_job = self.run_checks_job.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if missing_current_statistics is not UNSET:
            field_dict["missing_current_statistics"] = missing_current_statistics
        if missing_current_profiling_check_results is not UNSET:
            field_dict["missing_current_profiling_check_results"] = (
                missing_current_profiling_check_results
            )
        if table_checks is not UNSET:
            field_dict["table_checks"] = table_checks
        if column_checks is not UNSET:
            field_dict["column_checks"] = column_checks
        if run_checks_job is not UNSET:
            field_dict["run_checks_job"] = run_checks_job

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.check_container_model import CheckContainerModel
        from ..models.check_mining_proposal_model_column_checks import (
            CheckMiningProposalModelColumnChecks,
        )
        from ..models.check_search_filters import CheckSearchFilters

        d = src_dict.copy()
        missing_current_statistics = d.pop("missing_current_statistics", UNSET)

        missing_current_profiling_check_results = d.pop(
            "missing_current_profiling_check_results", UNSET
        )

        _table_checks = d.pop("table_checks", UNSET)
        table_checks: Union[Unset, CheckContainerModel]
        if isinstance(_table_checks, Unset):
            table_checks = UNSET
        else:
            table_checks = CheckContainerModel.from_dict(_table_checks)

        _column_checks = d.pop("column_checks", UNSET)
        column_checks: Union[Unset, CheckMiningProposalModelColumnChecks]
        if isinstance(_column_checks, Unset):
            column_checks = UNSET
        else:
            column_checks = CheckMiningProposalModelColumnChecks.from_dict(
                _column_checks
            )

        _run_checks_job = d.pop("run_checks_job", UNSET)
        run_checks_job: Union[Unset, CheckSearchFilters]
        if isinstance(_run_checks_job, Unset):
            run_checks_job = UNSET
        else:
            run_checks_job = CheckSearchFilters.from_dict(_run_checks_job)

        check_mining_proposal_model = cls(
            missing_current_statistics=missing_current_statistics,
            missing_current_profiling_check_results=missing_current_profiling_check_results,
            table_checks=table_checks,
            column_checks=column_checks,
            run_checks_job=run_checks_job,
        )

        check_mining_proposal_model.additional_properties = d
        return check_mining_proposal_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.compression_type import CompressionType
from ..models.json_format_type import JsonFormatType
from ..models.json_records_type import JsonRecordsType
from ..types import UNSET, Unset

T = TypeVar("T", bound="JsonFileFormatSpec")


@_attrs_define
class JsonFileFormatSpec:
    """
    Attributes:
        auto_detect (Union[Unset, bool]): Whether to auto-detect detect the names of the keys and data types of the
            values automatically.
        compression (Union[Unset, CompressionType]):
        no_compression_extension (Union[Unset, bool]): Whether the compression extension is present at the end of the
            file name.
        file_extension (Union[Unset, str]): Specifies a custom file name extension. The default is ".json".
        convert_strings_to_integers (Union[Unset, bool]): Whether strings representing integer values should be
            converted to a numerical type.
        dateformat (Union[Unset, str]): Specifies the date format to use when parsing dates.
        filename (Union[Unset, bool]): Whether or not an extra filename column should be included in the result.
        format_ (Union[Unset, JsonFormatType]):
        hive_partitioning (Union[Unset, bool]): Whether or not to interpret the path as a hive partitioned path.
        ignore_errors (Union[Unset, bool]): Whether to ignore parse errors (only possible when format is
            'newline_delimited').
        maximum_depth (Union[Unset, int]): Maximum nesting depth to which the automatic schema detection detects types.
            Set to -1 to fully detect nested JSON types.
        maximum_object_size (Union[Unset, int]): The maximum size of a JSON object (in bytes).
        records (Union[Unset, JsonRecordsType]):
        sample_size (Union[Unset, int]): The number of sample rows for auto detection of parameters.
        timestampformat (Union[Unset, str]): Specifies the date format to use when parsing timestamps.
    """

    auto_detect: Union[Unset, bool] = UNSET
    compression: Union[Unset, CompressionType] = UNSET
    no_compression_extension: Union[Unset, bool] = UNSET
    file_extension: Union[Unset, str] = UNSET
    convert_strings_to_integers: Union[Unset, bool] = UNSET
    dateformat: Union[Unset, str] = UNSET
    filename: Union[Unset, bool] = UNSET
    format_: Union[Unset, JsonFormatType] = UNSET
    hive_partitioning: Union[Unset, bool] = UNSET
    ignore_errors: Union[Unset, bool] = UNSET
    maximum_depth: Union[Unset, int] = UNSET
    maximum_object_size: Union[Unset, int] = UNSET
    records: Union[Unset, JsonRecordsType] = UNSET
    sample_size: Union[Unset, int] = UNSET
    timestampformat: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        auto_detect = self.auto_detect
        compression: Union[Unset, str] = UNSET
        if not isinstance(self.compression, Unset):
            compression = self.compression.value

        no_compression_extension = self.no_compression_extension
        file_extension = self.file_extension
        convert_strings_to_integers = self.convert_strings_to_integers
        dateformat = self.dateformat
        filename = self.filename
        format_: Union[Unset, str] = UNSET
        if not isinstance(self.format_, Unset):
            format_ = self.format_.value

        hive_partitioning = self.hive_partitioning
        ignore_errors = self.ignore_errors
        maximum_depth = self.maximum_depth
        maximum_object_size = self.maximum_object_size
        records: Union[Unset, str] = UNSET
        if not isinstance(self.records, Unset):
            records = self.records.value

        sample_size = self.sample_size
        timestampformat = self.timestampformat

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if auto_detect is not UNSET:
            field_dict["auto_detect"] = auto_detect
        if compression is not UNSET:
            field_dict["compression"] = compression
        if no_compression_extension is not UNSET:
            field_dict["no_compression_extension"] = no_compression_extension
        if file_extension is not UNSET:
            field_dict["file_extension"] = file_extension
        if convert_strings_to_integers is not UNSET:
            field_dict["convert_strings_to_integers"] = convert_strings_to_integers
        if dateformat is not UNSET:
            field_dict["dateformat"] = dateformat
        if filename is not UNSET:
            field_dict["filename"] = filename
        if format_ is not UNSET:
            field_dict["format"] = format_
        if hive_partitioning is not UNSET:
            field_dict["hive_partitioning"] = hive_partitioning
        if ignore_errors is not UNSET:
            field_dict["ignore_errors"] = ignore_errors
        if maximum_depth is not UNSET:
            field_dict["maximum_depth"] = maximum_depth
        if maximum_object_size is not UNSET:
            field_dict["maximum_object_size"] = maximum_object_size
        if records is not UNSET:
            field_dict["records"] = records
        if sample_size is not UNSET:
            field_dict["sample_size"] = sample_size
        if timestampformat is not UNSET:
            field_dict["timestampformat"] = timestampformat

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        auto_detect = d.pop("auto_detect", UNSET)

        _compression = d.pop("compression", UNSET)
        compression: Union[Unset, CompressionType]
        if isinstance(_compression, Unset):
            compression = UNSET
        else:
            compression = CompressionType(_compression)

        no_compression_extension = d.pop("no_compression_extension", UNSET)

        file_extension = d.pop("file_extension", UNSET)

        convert_strings_to_integers = d.pop("convert_strings_to_integers", UNSET)

        dateformat = d.pop("dateformat", UNSET)

        filename = d.pop("filename", UNSET)

        _format_ = d.pop("format", UNSET)
        format_: Union[Unset, JsonFormatType]
        if isinstance(_format_, Unset):
            format_ = UNSET
        else:
            format_ = JsonFormatType(_format_)

        hive_partitioning = d.pop("hive_partitioning", UNSET)

        ignore_errors = d.pop("ignore_errors", UNSET)

        maximum_depth = d.pop("maximum_depth", UNSET)

        maximum_object_size = d.pop("maximum_object_size", UNSET)

        _records = d.pop("records", UNSET)
        records: Union[Unset, JsonRecordsType]
        if isinstance(_records, Unset):
            records = UNSET
        else:
            records = JsonRecordsType(_records)

        sample_size = d.pop("sample_size", UNSET)

        timestampformat = d.pop("timestampformat", UNSET)

        json_file_format_spec = cls(
            auto_detect=auto_detect,
            compression=compression,
            no_compression_extension=no_compression_extension,
            file_extension=file_extension,
            convert_strings_to_integers=convert_strings_to_integers,
            dateformat=dateformat,
            filename=filename,
            format_=format_,
            hive_partitioning=hive_partitioning,
            ignore_errors=ignore_errors,
            maximum_depth=maximum_depth,
            maximum_object_size=maximum_object_size,
            records=records,
            sample_size=sample_size,
            timestampformat=timestampformat,
        )

        json_file_format_spec.additional_properties = d
        return json_file_format_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from http import HTTPStatus
from typing import Any, Dict, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.connection_model import ConnectionModel
from ...models.connection_test_model import ConnectionTestModel
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    json_body: ConnectionModel,
    verify_name_uniqueness: Union[Unset, None, bool] = UNSET,
) -> Dict[str, Any]:

    pass

    params: Dict[str, Any] = {}
    params["verifyNameUniqueness"] = verify_name_uniqueness

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    json_json_body = json_body.to_dict()

    return {
        "method": "post",
        "url": "api/datasource/testconnection",
        "json": json_json_body,
        "params": params,
    }


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[ConnectionTestModel]:
    if response.status_code == HTTPStatus.OK:
        response_200 = ConnectionTestModel.from_dict(response.json())

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[ConnectionTestModel]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    json_body: ConnectionModel,
    verify_name_uniqueness: Union[Unset, None, bool] = UNSET,
) -> Response[ConnectionTestModel]:
    """testConnection

     Checks if the given remote connection can be opened and if the credentials are valid

    Args:
        verify_name_uniqueness (Union[Unset, None, bool]):
        json_body (ConnectionModel): Connection model with a subset of parameters, excluding all
            nested objects.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[ConnectionTestModel]
    """

    kwargs = _get_kwargs(
        json_body=json_body,
        verify_name_uniqueness=verify_name_uniqueness,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: AuthenticatedClient,
    json_body: ConnectionModel,
    verify_name_uniqueness: Union[Unset, None, bool] = UNSET,
) -> Optional[ConnectionTestModel]:
    """testConnection

     Checks if the given remote connection can be opened and if the credentials are valid

    Args:
        verify_name_uniqueness (Union[Unset, None, bool]):
        json_body (ConnectionModel): Connection model with a subset of parameters, excluding all
            nested objects.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        ConnectionTestModel
    """

    return sync_detailed(
        client=client,
        json_body=json_body,
        verify_name_uniqueness=verify_name_uniqueness,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    json_body: ConnectionModel,
    verify_name_uniqueness: Union[Unset, None, bool] = UNSET,
) -> Response[ConnectionTestModel]:
    """testConnection

     Checks if the given remote connection can be opened and if the credentials are valid

    Args:
        verify_name_uniqueness (Union[Unset, None, bool]):
        json_body (ConnectionModel): Connection model with a subset of parameters, excluding all
            nested objects.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[ConnectionTestModel]
    """

    kwargs = _get_kwargs(
        json_body=json_body,
        verify_name_uniqueness=verify_name_uniqueness,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
    json_body: ConnectionModel,
    verify_name_uniqueness: Union[Unset, None, bool] = UNSET,
) -> Optional[ConnectionTestModel]:
    """testConnection

     Checks if the given remote connection can be opened and if the credentials are valid

    Args:
        verify_name_uniqueness (Union[Unset, None, bool]):
        json_body (ConnectionModel): Connection model with a subset of parameters, excluding all
            nested objects.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        ConnectionTestModel
    """

    return (
        await asyncio_detailed(
            client=client,
            json_body=json_body,
            verify_name_uniqueness=verify_name_uniqueness,
        )
    ).parsed



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.check_target import CheckTarget
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.check_container_type_model import CheckContainerTypeModel
    from ..models.check_model import CheckModel
    from ..models.parameter_definition_spec import ParameterDefinitionSpec


T = TypeVar("T", bound="CheckTemplate")


@_attrs_define
class CheckTemplate:
    """Model depicting a named data quality check that can potentially be enabled, regardless to its position in hierarchy
    tree.

        Attributes:
            check_target (Union[Unset, CheckTarget]):
            check_category (Union[Unset, str]): Data quality check category.
            check_name (Union[Unset, str]): Data quality check name that is used in YAML.
            help_text (Union[Unset, str]): Help text that describes the data quality check.
            check_container_type (Union[Unset, CheckContainerTypeModel]): Model identifying the check type and timescale of
                checks belonging to a container.
            sensor_name (Union[Unset, str]): Full sensor name.
            check_model (Union[Unset, CheckModel]): Model that returns the form definition and the form data to edit a
                single data quality check.
            sensor_parameters_definitions (Union[Unset, List['ParameterDefinitionSpec']]): List of sensor parameter fields
                definitions.
            rule_parameters_definitions (Union[Unset, List['ParameterDefinitionSpec']]): List of threshold (alerting) rule's
                parameters definitions (for a single rule, regardless of severity).
    """

    check_target: Union[Unset, CheckTarget] = UNSET
    check_category: Union[Unset, str] = UNSET
    check_name: Union[Unset, str] = UNSET
    help_text: Union[Unset, str] = UNSET
    check_container_type: Union[Unset, "CheckContainerTypeModel"] = UNSET
    sensor_name: Union[Unset, str] = UNSET
    check_model: Union[Unset, "CheckModel"] = UNSET
    sensor_parameters_definitions: Union[Unset, List["ParameterDefinitionSpec"]] = UNSET
    rule_parameters_definitions: Union[Unset, List["ParameterDefinitionSpec"]] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        check_target: Union[Unset, str] = UNSET
        if not isinstance(self.check_target, Unset):
            check_target = self.check_target.value

        check_category = self.check_category
        check_name = self.check_name
        help_text = self.help_text
        check_container_type: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.check_container_type, Unset):
            check_container_type = self.check_container_type.to_dict()

        sensor_name = self.sensor_name
        check_model: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.check_model, Unset):
            check_model = self.check_model.to_dict()

        sensor_parameters_definitions: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.sensor_parameters_definitions, Unset):
            sensor_parameters_definitions = []
            for (
                sensor_parameters_definitions_item_data
            ) in self.sensor_parameters_definitions:
                sensor_parameters_definitions_item = (
                    sensor_parameters_definitions_item_data.to_dict()
                )

                sensor_parameters_definitions.append(sensor_parameters_definitions_item)

        rule_parameters_definitions: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.rule_parameters_definitions, Unset):
            rule_parameters_definitions = []
            for (
                rule_parameters_definitions_item_data
            ) in self.rule_parameters_definitions:
                rule_parameters_definitions_item = (
                    rule_parameters_definitions_item_data.to_dict()
                )

                rule_parameters_definitions.append(rule_parameters_definitions_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if check_target is not UNSET:
            field_dict["check_target"] = check_target
        if check_category is not UNSET:
            field_dict["check_category"] = check_category
        if check_name is not UNSET:
            field_dict["check_name"] = check_name
        if help_text is not UNSET:
            field_dict["help_text"] = help_text
        if check_container_type is not UNSET:
            field_dict["check_container_type"] = check_container_type
        if sensor_name is not UNSET:
            field_dict["sensor_name"] = sensor_name
        if check_model is not UNSET:
            field_dict["check_model"] = check_model
        if sensor_parameters_definitions is not UNSET:
            field_dict["sensor_parameters_definitions"] = sensor_parameters_definitions
        if rule_parameters_definitions is not UNSET:
            field_dict["rule_parameters_definitions"] = rule_parameters_definitions

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.check_container_type_model import CheckContainerTypeModel
        from ..models.check_model import CheckModel
        from ..models.parameter_definition_spec import ParameterDefinitionSpec

        d = src_dict.copy()
        _check_target = d.pop("check_target", UNSET)
        check_target: Union[Unset, CheckTarget]
        if isinstance(_check_target, Unset):
            check_target = UNSET
        else:
            check_target = CheckTarget(_check_target)

        check_category = d.pop("check_category", UNSET)

        check_name = d.pop("check_name", UNSET)

        help_text = d.pop("help_text", UNSET)

        _check_container_type = d.pop("check_container_type", UNSET)
        check_container_type: Union[Unset, CheckContainerTypeModel]
        if isinstance(_check_container_type, Unset):
            check_container_type = UNSET
        else:
            check_container_type = CheckContainerTypeModel.from_dict(
                _check_container_type
            )

        sensor_name = d.pop("sensor_name", UNSET)

        _check_model = d.pop("check_model", UNSET)
        check_model: Union[Unset, CheckModel]
        if isinstance(_check_model, Unset):
            check_model = UNSET
        else:
            check_model = CheckModel.from_dict(_check_model)

        sensor_parameters_definitions = []
        _sensor_parameters_definitions = d.pop("sensor_parameters_definitions", UNSET)
        for sensor_parameters_definitions_item_data in (
            _sensor_parameters_definitions or []
        ):
            sensor_parameters_definitions_item = ParameterDefinitionSpec.from_dict(
                sensor_parameters_definitions_item_data
            )

            sensor_parameters_definitions.append(sensor_parameters_definitions_item)

        rule_parameters_definitions = []
        _rule_parameters_definitions = d.pop("rule_parameters_definitions", UNSET)
        for rule_parameters_definitions_item_data in _rule_parameters_definitions or []:
            rule_parameters_definitions_item = ParameterDefinitionSpec.from_dict(
                rule_parameters_definitions_item_data
            )

            rule_parameters_definitions.append(rule_parameters_definitions_item)

        check_template = cls(
            check_target=check_target,
            check_category=check_category,
            check_name=check_name,
            help_text=help_text,
            check_container_type=check_container_type,
            sensor_name=sensor_name,
            check_model=check_model,
            sensor_parameters_definitions=sensor_parameters_definitions,
            rule_parameters_definitions=rule_parameters_definitions,
        )

        check_template.additional_properties = d
        return check_template

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from typing import Any, Dict, List, Type, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

from ..types import UNSET, Unset

T = TypeVar("T", bound="DeleteStoredDataQueueJobParameters")


@_attrs_define
class DeleteStoredDataQueueJobParameters:
    """
    Attributes:
        connection (Union[Unset, str]): The connection name.
        full_table_name (Union[Unset, str]): The schema and table name. It is provided as *<schema_name>.<table_name>*,
            for example *public.fact_sales*. This filter does not support patterns.
        date_start (Union[Unset, datetime.date]): The start date (inclusive) to delete the data, based on the
            *time_period* column in Parquet files.
        date_end (Union[Unset, datetime.date]): The end date (inclusive) to delete the data, based on the *time_period*
            column in Parquet files.
        delete_errors (Union[Unset, bool]): Delete the data from the [errors](../../reference/parquetfiles/errors.md)
            table. Because the default value is *false*, this parameter must be set to *true* to delete the errors.
        delete_statistics (Union[Unset, bool]): Delete the data from the
            [statistics](../../reference/parquetfiles/statistics.md) table. Because the default value is *false*, this
            parameter must be set to *true* to delete the statistics.
        delete_check_results (Union[Unset, bool]): Delete the data from the
            [check_results](../../reference/parquetfiles/check_results.md) table. Because the default value is *false*, this
            parameter must be set to *true* to delete the check results.
        delete_sensor_readouts (Union[Unset, bool]): Delete the data from the
            [sensor_readouts](../../reference/parquetfiles/sensor_readouts.md) table. Because the default value is *false*,
            this parameter must be set to *true* to delete the sensor readouts.
        delete_error_samples (Union[Unset, bool]): Delete the data from the
            [error_samples](../../reference/parquetfiles/error_samples.md) table. Because the default value is *false*, this
            parameter must be set to *true* to delete the error samples.
        delete_incidents (Union[Unset, bool]): Delete the data from the
            [incidents](../../reference/parquetfiles/incidents.md) table. Because the default value is *false*, this
            parameter must be set to *true* to delete the incidents.
        delete_checks_configuration (Union[Unset, bool]): Delete the data quality configured checks from the table. They
            are detached from the configuration.Because the default value is *false*, this parameter must be set to *true*
            to delete the checks configuration.
        column_names (Union[Unset, List[str]]): The list of column names to delete the data for column level results or
            errors only for selected columns.
        check_category (Union[Unset, str]): The check category name, for example *volume* or *anomaly*.
        table_comparison_name (Union[Unset, str]): The name of a table comparison configuration. Deletes only table
            comparison results (and errors) for a given comparison.
        check_name (Union[Unset, str]): The name of a data quality check. Uses the short check name, for example
            *daily_row_count*.
        check_type (Union[Unset, str]): The type of checks whose results and errors should be deleted. For example, use
            *monitoring* to delete only monitoring checks data.
        sensor_name (Union[Unset, str]): The full sensor name whose results, checks based on the sensor, statistics and
            errors generated by the sensor sound be deleted. Uses a full sensor name, for example: *table/volume/row_count*.
        data_group_tag (Union[Unset, str]): The names of data groups in any of the
            *grouping_level_1*...*grouping_level_9* columns in the Parquet tables. Enables deleting data tagged for one data
            source or a subset of results when the group level is captured from a column in a monitored table.
        quality_dimension (Union[Unset, str]): The data quality dimension name, for example *Timeliness* or
            *Completeness*.
        time_gradient (Union[Unset, str]): The time gradient (time scale) of the sensor and check results that are
            captured.
        collector_category (Union[Unset, str]): The statistics collector category when statistics should be deleted. A
            statistics category is a group of statistics, for example *sampling* for the column value samples.
        collector_name (Union[Unset, str]): The statistics collector name when only statistics are deleted for a
            selected collector, for example *sample_values*.
        collector_target (Union[Unset, str]): The type of the target object for which the basic statistics are deleted.
            Supported values are *table* and *column*.
        incident_status_name (Union[Unset, str]): The incidents status name when only incidents are deleted, for example
            *muted*.
    """

    connection: Union[Unset, str] = UNSET
    full_table_name: Union[Unset, str] = UNSET
    date_start: Union[Unset, datetime.date] = UNSET
    date_end: Union[Unset, datetime.date] = UNSET
    delete_errors: Union[Unset, bool] = UNSET
    delete_statistics: Union[Unset, bool] = UNSET
    delete_check_results: Union[Unset, bool] = UNSET
    delete_sensor_readouts: Union[Unset, bool] = UNSET
    delete_error_samples: Union[Unset, bool] = UNSET
    delete_incidents: Union[Unset, bool] = UNSET
    delete_checks_configuration: Union[Unset, bool] = UNSET
    column_names: Union[Unset, List[str]] = UNSET
    check_category: Union[Unset, str] = UNSET
    table_comparison_name: Union[Unset, str] = UNSET
    check_name: Union[Unset, str] = UNSET
    check_type: Union[Unset, str] = UNSET
    sensor_name: Union[Unset, str] = UNSET
    data_group_tag: Union[Unset, str] = UNSET
    quality_dimension: Union[Unset, str] = UNSET
    time_gradient: Union[Unset, str] = UNSET
    collector_category: Union[Unset, str] = UNSET
    collector_name: Union[Unset, str] = UNSET
    collector_target: Union[Unset, str] = UNSET
    incident_status_name: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        connection = self.connection
        full_table_name = self.full_table_name
        date_start: Union[Unset, str] = UNSET
        if not isinstance(self.date_start, Unset):
            date_start = self.date_start.isoformat()

        date_end: Union[Unset, str] = UNSET
        if not isinstance(self.date_end, Unset):
            date_end = self.date_end.isoformat()

        delete_errors = self.delete_errors
        delete_statistics = self.delete_statistics
        delete_check_results = self.delete_check_results
        delete_sensor_readouts = self.delete_sensor_readouts
        delete_error_samples = self.delete_error_samples
        delete_incidents = self.delete_incidents
        delete_checks_configuration = self.delete_checks_configuration
        column_names: Union[Unset, List[str]] = UNSET
        if not isinstance(self.column_names, Unset):
            column_names = self.column_names

        check_category = self.check_category
        table_comparison_name = self.table_comparison_name
        check_name = self.check_name
        check_type = self.check_type
        sensor_name = self.sensor_name
        data_group_tag = self.data_group_tag
        quality_dimension = self.quality_dimension
        time_gradient = self.time_gradient
        collector_category = self.collector_category
        collector_name = self.collector_name
        collector_target = self.collector_target
        incident_status_name = self.incident_status_name

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if connection is not UNSET:
            field_dict["connection"] = connection
        if full_table_name is not UNSET:
            field_dict["fullTableName"] = full_table_name
        if date_start is not UNSET:
            field_dict["dateStart"] = date_start
        if date_end is not UNSET:
            field_dict["dateEnd"] = date_end
        if delete_errors is not UNSET:
            field_dict["deleteErrors"] = delete_errors
        if delete_statistics is not UNSET:
            field_dict["deleteStatistics"] = delete_statistics
        if delete_check_results is not UNSET:
            field_dict["deleteCheckResults"] = delete_check_results
        if delete_sensor_readouts is not UNSET:
            field_dict["deleteSensorReadouts"] = delete_sensor_readouts
        if delete_error_samples is not UNSET:
            field_dict["deleteErrorSamples"] = delete_error_samples
        if delete_incidents is not UNSET:
            field_dict["deleteIncidents"] = delete_incidents
        if delete_checks_configuration is not UNSET:
            field_dict["deleteChecksConfiguration"] = delete_checks_configuration
        if column_names is not UNSET:
            field_dict["columnNames"] = column_names
        if check_category is not UNSET:
            field_dict["checkCategory"] = check_category
        if table_comparison_name is not UNSET:
            field_dict["tableComparisonName"] = table_comparison_name
        if check_name is not UNSET:
            field_dict["checkName"] = check_name
        if check_type is not UNSET:
            field_dict["checkType"] = check_type
        if sensor_name is not UNSET:
            field_dict["sensorName"] = sensor_name
        if data_group_tag is not UNSET:
            field_dict["dataGroupTag"] = data_group_tag
        if quality_dimension is not UNSET:
            field_dict["qualityDimension"] = quality_dimension
        if time_gradient is not UNSET:
            field_dict["timeGradient"] = time_gradient
        if collector_category is not UNSET:
            field_dict["collectorCategory"] = collector_category
        if collector_name is not UNSET:
            field_dict["collectorName"] = collector_name
        if collector_target is not UNSET:
            field_dict["collectorTarget"] = collector_target
        if incident_status_name is not UNSET:
            field_dict["incidentStatusName"] = incident_status_name

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        connection = d.pop("connection", UNSET)

        full_table_name = d.pop("fullTableName", UNSET)

        _date_start = d.pop("dateStart", UNSET)
        date_start: Union[Unset, datetime.date]
        if isinstance(_date_start, Unset):
            date_start = UNSET
        else:
            date_start = isoparse(_date_start).date()

        _date_end = d.pop("dateEnd", UNSET)
        date_end: Union[Unset, datetime.date]
        if isinstance(_date_end, Unset):
            date_end = UNSET
        else:
            date_end = isoparse(_date_end).date()

        delete_errors = d.pop("deleteErrors", UNSET)

        delete_statistics = d.pop("deleteStatistics", UNSET)

        delete_check_results = d.pop("deleteCheckResults", UNSET)

        delete_sensor_readouts = d.pop("deleteSensorReadouts", UNSET)

        delete_error_samples = d.pop("deleteErrorSamples", UNSET)

        delete_incidents = d.pop("deleteIncidents", UNSET)

        delete_checks_configuration = d.pop("deleteChecksConfiguration", UNSET)

        column_names = cast(List[str], d.pop("columnNames", UNSET))

        check_category = d.pop("checkCategory", UNSET)

        table_comparison_name = d.pop("tableComparisonName", UNSET)

        check_name = d.pop("checkName", UNSET)

        check_type = d.pop("checkType", UNSET)

        sensor_name = d.pop("sensorName", UNSET)

        data_group_tag = d.pop("dataGroupTag", UNSET)

        quality_dimension = d.pop("qualityDimension", UNSET)

        time_gradient = d.pop("timeGradient", UNSET)

        collector_category = d.pop("collectorCategory", UNSET)

        collector_name = d.pop("collectorName", UNSET)

        collector_target = d.pop("collectorTarget", UNSET)

        incident_status_name = d.pop("incidentStatusName", UNSET)

        delete_stored_data_queue_job_parameters = cls(
            connection=connection,
            full_table_name=full_table_name,
            date_start=date_start,
            date_end=date_end,
            delete_errors=delete_errors,
            delete_statistics=delete_statistics,
            delete_check_results=delete_check_results,
            delete_sensor_readouts=delete_sensor_readouts,
            delete_error_samples=delete_error_samples,
            delete_incidents=delete_incidents,
            delete_checks_configuration=delete_checks_configuration,
            column_names=column_names,
            check_category=check_category,
            table_comparison_name=table_comparison_name,
            check_name=check_name,
            check_type=check_type,
            sensor_name=sensor_name,
            data_group_tag=data_group_tag,
            quality_dimension=quality_dimension,
            time_gradient=time_gradient,
            collector_category=collector_category,
            collector_name=collector_name,
            collector_target=collector_target,
            incident_status_name=incident_status_name,
        )

        delete_stored_data_queue_job_parameters.additional_properties = d
        return delete_stored_data_queue_job_parameters

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class CheckRunScheduleGroup(str, Enum):
    MONITORING_DAILY = "monitoring_daily"
    MONITORING_MONTHLY = "monitoring_monthly"
    PARTITIONED_DAILY = "partitioned_daily"
    PARTITIONED_MONTHLY = "partitioned_monthly"
    PROFILING = "profiling"

    def __str__(self) -> str:
        return str(self.value)



from http import HTTPStatus
from typing import Any, Dict, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.table_quality_policy_list_model import TableQualityPolicyListModel
from ...types import Response


def _get_kwargs(
    pattern_name: str,
    *,
    json_body: TableQualityPolicyListModel,
) -> Dict[str, Any]:

    pass

    json_json_body = json_body.to_dict()

    return {
        "method": "post",
        "url": "api/policies/checks/table/{patternName}/target".format(
            patternName=pattern_name,
        ),
        "json": json_json_body,
    }


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Any]:
    if response.status_code == HTTPStatus.CREATED:
        return None
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Any]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    pattern_name: str,
    *,
    client: AuthenticatedClient,
    json_body: TableQualityPolicyListModel,
) -> Response[Any]:
    """createTableQualityPolicyTarget

     Creates (adds) a new default table-level checks pattern configuration (a table-level data quality
    policy).

    Args:
        pattern_name (str):
        json_body (TableQualityPolicyListModel): Default table-level checks pattern (data quality
            policy) list model

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(
        pattern_name=pattern_name,
        json_body=json_body,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


async def asyncio_detailed(
    pattern_name: str,
    *,
    client: AuthenticatedClient,
    json_body: TableQualityPolicyListModel,
) -> Response[Any]:
    """createTableQualityPolicyTarget

     Creates (adds) a new default table-level checks pattern configuration (a table-level data quality
    policy).

    Args:
        pattern_name (str):
        json_body (TableQualityPolicyListModel): Default table-level checks pattern (data quality
            policy) list model

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(
        pattern_name=pattern_name,
        json_body=json_body,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.physical_table_name import PhysicalTableName


T = TypeVar("T", bound="DomainConnectionTableKey")


@_attrs_define
class DomainConnectionTableKey:
    """Table key that identifies a table in the data quality cache or a data lineage cache.

    Attributes:
        data_domain (Union[Unset, str]): Data domain name.
        connection_name (Union[Unset, str]): Connection name.
        physical_table_name (Union[Unset, PhysicalTableName]):
        compact_key (Union[Unset, str]): A string key that identifies the table within the data domain. It is based on
            the connection, schema and table names.
    """

    data_domain: Union[Unset, str] = UNSET
    connection_name: Union[Unset, str] = UNSET
    physical_table_name: Union[Unset, "PhysicalTableName"] = UNSET
    compact_key: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        data_domain = self.data_domain
        connection_name = self.connection_name
        physical_table_name: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.physical_table_name, Unset):
            physical_table_name = self.physical_table_name.to_dict()

        compact_key = self.compact_key

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if data_domain is not UNSET:
            field_dict["data_domain"] = data_domain
        if connection_name is not UNSET:
            field_dict["connection_name"] = connection_name
        if physical_table_name is not UNSET:
            field_dict["physical_table_name"] = physical_table_name
        if compact_key is not UNSET:
            field_dict["compact_key"] = compact_key

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.physical_table_name import PhysicalTableName

        d = src_dict.copy()
        data_domain = d.pop("data_domain", UNSET)

        connection_name = d.pop("connection_name", UNSET)

        _physical_table_name = d.pop("physical_table_name", UNSET)
        physical_table_name: Union[Unset, PhysicalTableName]
        if isinstance(_physical_table_name, Unset):
            physical_table_name = UNSET
        else:
            physical_table_name = PhysicalTableName.from_dict(_physical_table_name)

        compact_key = d.pop("compact_key", UNSET)

        domain_connection_table_key = cls(
            data_domain=data_domain,
            connection_name=connection_name,
            physical_table_name=physical_table_name,
            compact_key=compact_key,
        )

        domain_connection_table_key.additional_properties = d
        return domain_connection_table_key

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

from ..models.check_run_schedule_group import CheckRunScheduleGroup
from ..models.effective_schedule_level_model import EffectiveScheduleLevelModel
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.duration import Duration


T = TypeVar("T", bound="EffectiveScheduleModel")


@_attrs_define
class EffectiveScheduleModel:
    """Model of a configured schedule (enabled on connection or table) or schedule override (on check). Describes the CRON
    expression and the time of the upcoming execution, as well as the duration until this time.

        Attributes:
            schedule_group (Union[Unset, CheckRunScheduleGroup]):
            schedule_level (Union[Unset, EffectiveScheduleLevelModel]):
            cron_expression (Union[Unset, str]): Field value for a CRON expression defining the scheduling.
            time_of_execution (Union[Unset, datetime.datetime]): Field value for the time at which the scheduled checks will
                be executed.
            time_until_execution (Union[Unset, Duration]):
            disabled (Union[Unset, bool]): Field value stating if the schedule has been explicitly disabled.
    """

    schedule_group: Union[Unset, CheckRunScheduleGroup] = UNSET
    schedule_level: Union[Unset, EffectiveScheduleLevelModel] = UNSET
    cron_expression: Union[Unset, str] = UNSET
    time_of_execution: Union[Unset, datetime.datetime] = UNSET
    time_until_execution: Union[Unset, "Duration"] = UNSET
    disabled: Union[Unset, bool] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        schedule_group: Union[Unset, str] = UNSET
        if not isinstance(self.schedule_group, Unset):
            schedule_group = self.schedule_group.value

        schedule_level: Union[Unset, str] = UNSET
        if not isinstance(self.schedule_level, Unset):
            schedule_level = self.schedule_level.value

        cron_expression = self.cron_expression
        time_of_execution: Union[Unset, str] = UNSET
        if not isinstance(self.time_of_execution, Unset):
            time_of_execution = self.time_of_execution.isoformat()

        time_until_execution: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.time_until_execution, Unset):
            time_until_execution = self.time_until_execution.to_dict()

        disabled = self.disabled

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if schedule_group is not UNSET:
            field_dict["schedule_group"] = schedule_group
        if schedule_level is not UNSET:
            field_dict["schedule_level"] = schedule_level
        if cron_expression is not UNSET:
            field_dict["cron_expression"] = cron_expression
        if time_of_execution is not UNSET:
            field_dict["time_of_execution"] = time_of_execution
        if time_until_execution is not UNSET:
            field_dict["time_until_execution"] = time_until_execution
        if disabled is not UNSET:
            field_dict["disabled"] = disabled

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.duration import Duration

        d = src_dict.copy()
        _schedule_group = d.pop("schedule_group", UNSET)
        schedule_group: Union[Unset, CheckRunScheduleGroup]
        if isinstance(_schedule_group, Unset):
            schedule_group = UNSET
        else:
            schedule_group = CheckRunScheduleGroup(_schedule_group)

        _schedule_level = d.pop("schedule_level", UNSET)
        schedule_level: Union[Unset, EffectiveScheduleLevelModel]
        if isinstance(_schedule_level, Unset):
            schedule_level = UNSET
        else:
            schedule_level = EffectiveScheduleLevelModel(_schedule_level)

        cron_expression = d.pop("cron_expression", UNSET)

        _time_of_execution = d.pop("time_of_execution", UNSET)
        time_of_execution: Union[Unset, datetime.datetime]
        if isinstance(_time_of_execution, Unset):
            time_of_execution = UNSET
        else:
            time_of_execution = isoparse(_time_of_execution)

        _time_until_execution = d.pop("time_until_execution", UNSET)
        time_until_execution: Union[Unset, Duration]
        if isinstance(_time_until_execution, Unset):
            time_until_execution = UNSET
        else:
            time_until_execution = Duration.from_dict(_time_until_execution)

        disabled = d.pop("disabled", UNSET)

        effective_schedule_model = cls(
            schedule_group=schedule_group,
            schedule_level=schedule_level,
            cron_expression=cron_expression,
            time_of_execution=time_of_execution,
            time_until_execution=time_until_execution,
            disabled=disabled,
        )

        effective_schedule_model.additional_properties = d
        return effective_schedule_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
